Class: Sentdm::Models::BillingContactInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/billing_contact_info.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, name:, address: nil, phone: nil) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::BillingContactInfo for more details.

Billing contact information for a profile. Required when billing_model is “profile” or “profile_and_organization”.

Parameters:

  • email (String)

    Email address where invoices will be sent (required)

  • name (String)

    Full name of the billing contact or company (required)

  • address (String, nil) (defaults to: nil)

    Billing address (optional). Free-form text including street, city, state, postal

  • phone (String, nil) (defaults to: nil)

    Phone number for the billing contact (optional)



# File 'lib/sentdm/models/billing_contact_info.rb', line 31

Instance Attribute Details

#addressString?

Billing address (optional). Free-form text including street, city, state, postal code, and country.

Returns:

  • (String, nil)


23
# File 'lib/sentdm/models/billing_contact_info.rb', line 23

optional :address, String, nil?: true

#emailString

Email address where invoices will be sent (required)

Returns:

  • (String)


10
# File 'lib/sentdm/models/billing_contact_info.rb', line 10

required :email, String

#nameString

Full name of the billing contact or company (required)

Returns:

  • (String)


16
# File 'lib/sentdm/models/billing_contact_info.rb', line 16

required :name, String

#phoneString?

Phone number for the billing contact (optional)

Returns:

  • (String, nil)


29
# File 'lib/sentdm/models/billing_contact_info.rb', line 29

optional :phone, String, nil?: true