Class: Sentdm::Models::BrandUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/brand_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand_id:, brand:, test_mode: nil, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::BrandUpdateParams for more details.

Parameters:

  • brand_id (String)
  • brand (Sentdm::Models::BrandData)

    Brand and KYC information

  • test_mode (Boolean) (defaults to: nil)

    Test mode flag - when true, the operation is simulated without side effects

  • idempotency_key (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/brand_update_params.rb', line 33

Instance Attribute Details

#brandSentdm::Models::BrandData

Brand and KYC information



19
# File 'lib/sentdm/models/brand_update_params.rb', line 19

required :brand, -> { Sentdm::BrandData }

#brand_idString

Returns:

  • (String)


13
# File 'lib/sentdm/models/brand_update_params.rb', line 13

required :brand_id, String

#idempotency_keyString?

Returns:

  • (String, nil)


31
# File 'lib/sentdm/models/brand_update_params.rb', line 31

optional :idempotency_key, String

#test_modeBoolean?

Test mode flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


26
# File 'lib/sentdm/models/brand_update_params.rb', line 26

optional :test_mode, Sentdm::Internal::Type::Boolean