Class: Sentdm::Models::BrandsBrandData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::BrandsBrandData
- Defined in:
- lib/sentdm/models/brands_brand_data.rb
Instance Attribute Summary collapse
-
#business ⇒ Sentdm::Models::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandBusinessInfo?
Business details and address for brand KYC.
-
#compliance ⇒ Sentdm::Models::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandComplianceInfo
Compliance and TCR information for brand registration.
-
#contact ⇒ Sentdm::Models::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandContactInfo
Contact information for brand KYC.
Instance Method Summary collapse
-
#initialize(compliance:, contact:, business: nil) ⇒ Object
constructor
Brand and KYC data grouped into contact, business, and compliance sections.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(compliance:, contact:, business: nil) ⇒ Object
Brand and KYC data grouped into contact, business, and compliance sections
|
|
# File 'lib/sentdm/models/brands_brand_data.rb', line 28
|
Instance Attribute Details
#business ⇒ Sentdm::Models::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandBusinessInfo?
Business details and address for brand KYC
24 25 26 |
# File 'lib/sentdm/models/brands_brand_data.rb', line 24 optional :business, -> { Sentdm::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandBusinessInfo }, nil?: true |
#compliance ⇒ Sentdm::Models::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandComplianceInfo
Compliance and TCR information for brand registration
10 11 |
# File 'lib/sentdm/models/brands_brand_data.rb', line 10 required :compliance, -> { Sentdm::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandComplianceInfo } |
#contact ⇒ Sentdm::Models::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandContactInfo
Contact information for brand KYC
17 18 |
# File 'lib/sentdm/models/brands_brand_data.rb', line 17 required :contact, -> { Sentdm::SentDmServicesEndpointsCustomerApIv3ContractsRequestsBrandsBrandContactInfo } |