Class: Sentdm::Models::ContactCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/contact_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone_number: nil, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ContactCreateParams for more details.

Parameters:

  • phone_number (String) (defaults to: nil)

    Phone number of the contact to create

  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects

  • idempotency_key (String) (defaults to: nil)
  • x_profile_id (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/contact_create_params.rb', line 33

Instance Attribute Details

#idempotency_keyString?

Returns:

  • (String, nil)


26
# File 'lib/sentdm/models/contact_create_params.rb', line 26

optional :idempotency_key, String

#phone_numberString?

Phone number of the contact to create

Returns:

  • (String, nil)


14
# File 'lib/sentdm/models/contact_create_params.rb', line 14

optional :phone_number, String

#sandboxBoolean?

Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


21
# File 'lib/sentdm/models/contact_create_params.rb', line 21

optional :sandbox, Sentdm::Internal::Type::Boolean

#x_profile_idString?

Returns:

  • (String, nil)


31
# File 'lib/sentdm/models/contact_create_params.rb', line 31

optional :x_profile_id, String