Class: Sentdm::Models::ContactListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ContactListResponse::Data
- Defined in:
- lib/sentdm/models/contact_list_response.rb
Overview
Defined Under Namespace
Classes: Contact, Pagination
Instance Attribute Summary collapse
-
#contacts ⇒ Array<Sentdm::Models::ContactListResponse::Data::Contact>?
List of contacts.
-
#pagination ⇒ Sentdm::Models::ContactListResponse::Data::Pagination?
Pagination metadata for list responses.
Instance Method Summary collapse
-
#initialize(id: nil, available_channels: nil, country_code: nil, created_at: nil, default_channel: nil, format_e164: nil, format_international: nil, format_national: nil, format_rfc: nil, is_inherited: nil, opt_out: nil, phone_number: nil, region_code: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Contact for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, available_channels: nil, country_code: nil, created_at: nil, default_channel: nil, format_e164: nil, format_international: nil, format_national: nil, format_rfc: nil, is_inherited: nil, opt_out: nil, phone_number: nil, region_code: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Contact for more details.
Contact response for v3 API Uses snake_case for JSON property names
|
|
# File 'lib/sentdm/models/contact_list_response.rb', line 150
|
Instance Attribute Details
#contacts ⇒ Array<Sentdm::Models::ContactListResponse::Data::Contact>?
List of contacts
48 49 |
# File 'lib/sentdm/models/contact_list_response.rb', line 48 optional :contacts, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::Models::ContactListResponse::Data::Contact] } |
#pagination ⇒ Sentdm::Models::ContactListResponse::Data::Pagination?
Pagination metadata for list responses
55 |
# File 'lib/sentdm/models/contact_list_response.rb', line 55 optional :pagination, -> { Sentdm::Models::ContactListResponse::Data::Pagination } |