Class: Sentdm::Models::ContactMessageSummary::ChannelScore

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/contact_message_summary.rb,
sig/sentdm/models/contact_message_summary.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel: nil, fail_score: nil, success_score: nil) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ContactMessageSummary::ChannelScore for more details.

Parameters:

  • channel (String) (defaults to: nil)
  • fail_score (Integer) (defaults to: nil)

    Percentage (0-100) of messages on this channel that ended in FAILED.

  • success_score (Integer) (defaults to: nil)

    Percentage (0-100) of messages on this channel that reached a successful termina



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/sentdm/models/contact_message_summary.rb', line 45

class ChannelScore < Sentdm::Internal::Type::BaseModel
  # @!attribute channel
  #
  #   @return [String, nil]
  optional :channel, String

  # @!attribute fail_score
  #   Percentage (0-100) of messages on this channel that ended in FAILED.
  #
  #   @return [Integer, nil]
  optional :fail_score, Integer

  # @!attribute success_score
  #   Percentage (0-100) of messages on this channel that reached a successful
  #   terminal state: SENT/DELIVERED/READ for outbound, RECEIVED for inbound.
  #
  #   @return [Integer, nil]
  optional :success_score, Integer

  # @!method initialize(channel: nil, fail_score: nil, success_score: nil)
  #   Some parameter documentations has been truncated, see
  #   {Sentdm::Models::ContactMessageSummary::ChannelScore} for more details.
  #
  #   @param channel [String]
  #
  #   @param fail_score [Integer] Percentage (0-100) of messages on this channel that ended in FAILED.
  #
  #   @param success_score [Integer] Percentage (0-100) of messages on this channel that reached a successful termina
end

Instance Attribute Details

#channelString?

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/sentdm/models/contact_message_summary.rb', line 49

optional :channel, String

#fail_scoreInteger?

Percentage (0-100) of messages on this channel that ended in FAILED.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


55
# File 'lib/sentdm/models/contact_message_summary.rb', line 55

optional :fail_score, Integer

#success_scoreInteger?

Percentage (0-100) of messages on this channel that reached a successful terminal state: SENT/DELIVERED/READ for outbound, RECEIVED for inbound.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


62
# File 'lib/sentdm/models/contact_message_summary.rb', line 62

optional :success_score, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


76
# File 'sig/sentdm/models/contact_message_summary.rbs', line 76

def to_hash: -> {