Class: Sentdm::Models::ContactUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ContactUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sentdm/models/contact_update_params.rb
Overview
Instance Attribute Summary collapse
-
#default_channel ⇒ String?
Default messaging channel: “sms” or “whatsapp”.
- #id ⇒ String
- #idempotency_key ⇒ String?
-
#opt_out ⇒ Boolean?
Whether the contact has opted out of messaging.
-
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution.
- #x_profile_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, default_channel: nil, opt_out: nil, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContactUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, default_channel: nil, opt_out: nil, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::ContactUpdateParams for more details.
|
|
# File 'lib/sentdm/models/contact_update_params.rb', line 45
|
Instance Attribute Details
#default_channel ⇒ String?
Default messaging channel: “sms” or “whatsapp”
19 |
# File 'lib/sentdm/models/contact_update_params.rb', line 19 optional :default_channel, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/sentdm/models/contact_update_params.rb', line 13 required :id, String |
#idempotency_key ⇒ String?
38 |
# File 'lib/sentdm/models/contact_update_params.rb', line 38 optional :idempotency_key, String |
#opt_out ⇒ Boolean?
Whether the contact has opted out of messaging. Single source of truth — opt-out is per-contact, not per-channel.
26 |
# File 'lib/sentdm/models/contact_update_params.rb', line 26 optional :opt_out, Sentdm::Internal::Type::Boolean, nil?: true |
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
33 |
# File 'lib/sentdm/models/contact_update_params.rb', line 33 optional :sandbox, Sentdm::Internal::Type::Boolean |
#x_profile_id ⇒ String?
43 |
# File 'lib/sentdm/models/contact_update_params.rb', line 43 optional :x_profile_id, String |