Class: Sentdm::Models::MeRetrieveResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/me_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Channels, Profile, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allow_contact_sharing: nil, allow_template_sharing: nil, billing_model: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil) ⇒ Object

Profile configuration settings

Parameters:

  • allow_contact_sharing (Boolean, nil) (defaults to: nil)

    Whether contacts are shared across profiles in the organization

  • allow_template_sharing (Boolean, nil) (defaults to: nil)

    Whether templates are shared across profiles in the organization

  • billing_model (String, nil) (defaults to: nil)

    Billing model: profile, organization, or profile_and_organization

  • inherit_contacts (Boolean, nil) (defaults to: nil)

    Whether this profile inherits contacts from the organization

  • inherit_tcr_brand (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR brand from the organization

  • inherit_tcr_campaign (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR campaign from the organization

  • inherit_templates (Boolean, nil) (defaults to: nil)

    Whether this profile inherits templates from the organization



# File 'lib/sentdm/models/me_retrieve_response.rb', line 132

Instance Attribute Details

#channelsSentdm::Models::MeRetrieveResponse::Data::Channels?

Messaging channel configuration. All three channels are always present. Each channel has a “configured” flag; configured channels expose additional details.



60
# File 'lib/sentdm/models/me_retrieve_response.rb', line 60

optional :channels, -> { Sentdm::Models::MeRetrieveResponse::Data::Channels }

#created_atTime?

When the account was created

Returns:

  • (Time, nil)


66
# File 'lib/sentdm/models/me_retrieve_response.rb', line 66

optional :created_at, Time

#descriptionString?

Account description

Returns:

  • (String, nil)


72
# File 'lib/sentdm/models/me_retrieve_response.rb', line 72

optional :description, String, nil?: true

#emailString?

Contact email address

Returns:

  • (String, nil)


78
# File 'lib/sentdm/models/me_retrieve_response.rb', line 78

optional :email, String, nil?: true

#iconString?

Account icon URL

Returns:

  • (String, nil)


84
# File 'lib/sentdm/models/me_retrieve_response.rb', line 84

optional :icon, String, nil?: true

#idString?

Customer ID (organization, account, or profile)

Returns:

  • (String, nil)


53
# File 'lib/sentdm/models/me_retrieve_response.rb', line 53

optional :id, String

#nameString?

Account name

Returns:

  • (String, nil)


90
# File 'lib/sentdm/models/me_retrieve_response.rb', line 90

optional :name, String

#organization_idString?

Organization ID (only for profile type — the parent organization)

Returns:

  • (String, nil)


96
# File 'lib/sentdm/models/me_retrieve_response.rb', line 96

optional :organization_id, String, nil?: true

#profilesArray<Sentdm::Models::MeRetrieveResponse::Data::Profile>?

List of profiles (populated for organization type, empty for user and profile types)



103
104
# File 'lib/sentdm/models/me_retrieve_response.rb', line 103

optional :profiles,
-> { Sentdm::Internal::Type::ArrayOf[Sentdm::Models::MeRetrieveResponse::Data::Profile] }

#settingsSentdm::Models::MeRetrieveResponse::Data::Settings?

Profile configuration settings



110
# File 'lib/sentdm/models/me_retrieve_response.rb', line 110

optional :settings, -> { Sentdm::Models::MeRetrieveResponse::Data::Settings }, nil?: true

#short_nameString?

Short name / abbreviation (only for profile type)

Returns:

  • (String, nil)


116
# File 'lib/sentdm/models/me_retrieve_response.rb', line 116

optional :short_name, String, nil?: true

#statusString?

Profile status (only for profile type): incomplete, pending_review, approved, etc.

Returns:

  • (String, nil)


123
# File 'lib/sentdm/models/me_retrieve_response.rb', line 123

optional :status, String, nil?: true

#typeString?

Account type: “organization” (has profiles), “user” (no profiles), or “profile” (child of an organization)

Returns:

  • (String, nil)


130
# File 'lib/sentdm/models/me_retrieve_response.rb', line 130

optional :type, String