Class: Sentdm::Models::MeRetrieveResponse::Data::Settings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/me_retrieve_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Sentdm::Internal::Type::BaseModel

Instance Attribute Details

#allow_contact_sharingBoolean?

Whether contacts are shared across profiles in the organization

Returns:

  • (Boolean, nil)


425
# File 'lib/sentdm/models/me_retrieve_response.rb', line 425

optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#allow_template_sharingBoolean?

Whether templates are shared across profiles in the organization

Returns:

  • (Boolean, nil)


431
# File 'lib/sentdm/models/me_retrieve_response.rb', line 431

optional :allow_template_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#billing_modelString?

Billing model: profile, organization, or profile_and_organization

Returns:

  • (String, nil)


437
# File 'lib/sentdm/models/me_retrieve_response.rb', line 437

optional :billing_model, String, nil?: true

#inherit_contactsBoolean?

Whether this profile inherits contacts from the organization

Returns:

  • (Boolean, nil)


443
# File 'lib/sentdm/models/me_retrieve_response.rb', line 443

optional :inherit_contacts, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_brandBoolean?

Whether this profile inherits TCR brand from the organization

Returns:

  • (Boolean, nil)


449
# File 'lib/sentdm/models/me_retrieve_response.rb', line 449

optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_campaignBoolean?

Whether this profile inherits TCR campaign from the organization

Returns:

  • (Boolean, nil)


455
# File 'lib/sentdm/models/me_retrieve_response.rb', line 455

optional :inherit_tcr_campaign, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_templatesBoolean?

Whether this profile inherits templates from the organization

Returns:

  • (Boolean, nil)


461
# File 'lib/sentdm/models/me_retrieve_response.rb', line 461

optional :inherit_templates, Sentdm::Internal::Type::Boolean, nil?: true