Class: Sentdm::Models::MessageRetrieveActivitiesResponse::Data::Activity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/message_retrieve_activities_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(activities: nil, message_id: nil) ⇒ Object

Response for GET /messages/id/activities

Parameters:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/sentdm/models/message_retrieve_activities_response.rb', line 64

class Activity < Sentdm::Internal::Type::BaseModel
  # @!attribute active_contact_price
  #   Active contact markup applied on top of the channel cost, formatted to 4 decimal
  #   places.
  #
  #   @return [String, nil]
  optional :active_contact_price, String, nil?: true

  # @!attribute description
  #   Human-readable description of the activity
  #
  #   @return [String, nil]
  optional :description, String

  # @!attribute from
  #   Sender phone number for this activity (the customer's sending number for
  #   outbound, the external sender for inbound). Null when not reported by the
  #   provider.
  #
  #   @return [String, nil]
  optional :from, String, nil?: true

  # @!attribute price
  #   Channel cost for this activity (e.g., SMS/WhatsApp provider cost), formatted to
  #   4 decimal places.
  #
  #   @return [String, nil]
  optional :price, String, nil?: true

  # @!attribute status
  #   Activity status (e.g., QUEUED, PROCESSED, ROUTED, SENT, DELIVERED, FAILED)
  #
  #   @return [String, nil]
  optional :status, String

  # @!attribute timestamp
  #   When this activity occurred
  #
  #   @return [Time, nil]
  optional :timestamp, Time

  # @!method initialize(active_contact_price: nil, description: nil, from: nil, price: nil, status: nil, timestamp: nil)
  #   Some parameter documentations has been truncated, see
  #   {Sentdm::Models::MessageRetrieveActivitiesResponse::Data::Activity} for more
  #   details.
  #
  #   A single message activity event for v3 API
  #
  #   @param active_contact_price [String, nil] Active contact markup applied on top of the channel cost, formatted to 4 decimal
  #
  #   @param description [String] Human-readable description of the activity
  #
  #   @param from [String, nil] Sender phone number for this activity (the customer's sending number for outboun
  #
  #   @param price [String, nil] Channel cost for this activity (e.g., SMS/WhatsApp provider cost), formatted to
  #
  #   @param status [String] Activity status (e.g., QUEUED, PROCESSED, ROUTED, SENT, DELIVERED, FAILED)
  #
  #   @param timestamp [Time] When this activity occurred
end

Instance Attribute Details

#active_contact_priceString?

Active contact markup applied on top of the channel cost, formatted to 4 decimal places.

Returns:

  • (String, nil)


70
# File 'lib/sentdm/models/message_retrieve_activities_response.rb', line 70

optional :active_contact_price, String, nil?: true

#descriptionString?

Human-readable description of the activity

Returns:

  • (String, nil)


76
# File 'lib/sentdm/models/message_retrieve_activities_response.rb', line 76

optional :description, String

#fromString?

Sender phone number for this activity (the customer’s sending number for outbound, the external sender for inbound). Null when not reported by the provider.

Returns:

  • (String, nil)


84
# File 'lib/sentdm/models/message_retrieve_activities_response.rb', line 84

optional :from, String, nil?: true

#priceString?

Channel cost for this activity (e.g., SMS/WhatsApp provider cost), formatted to 4 decimal places.

Returns:

  • (String, nil)


91
# File 'lib/sentdm/models/message_retrieve_activities_response.rb', line 91

optional :price, String, nil?: true

#statusString?

Activity status (e.g., QUEUED, PROCESSED, ROUTED, SENT, DELIVERED, FAILED)

Returns:

  • (String, nil)


97
# File 'lib/sentdm/models/message_retrieve_activities_response.rb', line 97

optional :status, String

#timestampTime?

When this activity occurred

Returns:

  • (Time, nil)


103
# File 'lib/sentdm/models/message_retrieve_activities_response.rb', line 103

optional :timestamp, Time