Class: Sentdm::Models::MessageSendResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::MessageSendResponse::Data
- Defined in:
- lib/sentdm/models/message_send_response.rb
Overview
Defined Under Namespace
Classes: Recipient
Instance Attribute Summary collapse
-
#recipients ⇒ Array<Sentdm::Models::MessageSendResponse::Data::Recipient>?
Per-recipient message results.
-
#status ⇒ String?
Overall request status: “QUEUED” when the batch has been accepted and published to Kafka.
-
#template_id ⇒ String?
Template ID that was used.
-
#template_name ⇒ String?
Template display name.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Sentdm::Internal::Type::BaseModel
Instance Attribute Details
#recipients ⇒ Array<Sentdm::Models::MessageSendResponse::Data::Recipient>?
Per-recipient message results
48 49 |
# File 'lib/sentdm/models/message_send_response.rb', line 48 optional :recipients, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::Models::MessageSendResponse::Data::Recipient] } |
#status ⇒ String?
Overall request status: “QUEUED” when the batch has been accepted and published to Kafka.
56 |
# File 'lib/sentdm/models/message_send_response.rb', line 56 optional :status, String |
#template_id ⇒ String?
Template ID that was used
62 |
# File 'lib/sentdm/models/message_send_response.rb', line 62 optional :template_id, String |
#template_name ⇒ String?
Template display name
68 |
# File 'lib/sentdm/models/message_send_response.rb', line 68 optional :template_name, String |