Class: Sentdm::Models::MutationRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/mutation_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(sandbox: nil) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::MutationRequest for more details.

Parameters:

  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects



# File 'lib/sentdm/models/mutation_request.rb', line 13

Instance Attribute Details

#sandboxBoolean?

Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


11
# File 'lib/sentdm/models/mutation_request.rb', line 11

optional :sandbox, Sentdm::Internal::Type::Boolean