Class: Sentdm::Models::ProfileCompleteParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileCompleteParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sentdm/models/profile_complete_params.rb
Overview
Instance Attribute Summary collapse
- #idempotency_key ⇒ String?
- #profile_id ⇒ String
-
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution.
-
#web_hook_url ⇒ String
Webhook URL to call when profile completion finishes (success or failure).
- #x_profile_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(profile_id:, web_hook_url:, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProfileCompleteParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(profile_id:, web_hook_url:, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::ProfileCompleteParams for more details.
|
|
# File 'lib/sentdm/models/profile_complete_params.rb', line 38
|
Instance Attribute Details
#idempotency_key ⇒ String?
31 |
# File 'lib/sentdm/models/profile_complete_params.rb', line 31 optional :idempotency_key, String |
#profile_id ⇒ String
13 |
# File 'lib/sentdm/models/profile_complete_params.rb', line 13 required :profile_id, String |
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
26 |
# File 'lib/sentdm/models/profile_complete_params.rb', line 26 optional :sandbox, Sentdm::Internal::Type::Boolean |
#web_hook_url ⇒ String
Webhook URL to call when profile completion finishes (success or failure)
19 |
# File 'lib/sentdm/models/profile_complete_params.rb', line 19 required :web_hook_url, String, api_name: :webHookUrl |
#x_profile_id ⇒ String?
36 |
# File 'lib/sentdm/models/profile_complete_params.rb', line 36 optional :x_profile_id, String |