Class: Sentdm::Models::ProfileCreateParams::BillingContact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/profile_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allow_contact_sharing: nil, allow_template_sharing: nil, billing_contact: nil, billing_model: nil, brand: nil, description: nil, icon: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, name: nil, payment_details: nil, sandbox: nil, short_name: nil, whatsapp_business_account: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ProfileCreateParams for more details.

Parameters:

  • allow_contact_sharing (Boolean) (defaults to: nil)

    Whether contacts are shared across profiles (default: false)

  • allow_template_sharing (Boolean) (defaults to: nil)

    Whether templates are shared across profiles (default: false)

  • billing_contact (Sentdm::Models::ProfileCreateParams::BillingContact, nil) (defaults to: nil)

    Billing contact information for a profile.

  • billing_model (String, nil) (defaults to: nil)

    Billing model: profile, organization, or profile_and_organization (default: prof

  • brand (Sentdm::Models::ProfileCreateParams::Brand, nil) (defaults to: nil)

    Brand and KYC data grouped into contact, business, and compliance sections

  • description (String, nil) (defaults to: nil)

    Profile description (optional)

  • icon (String, nil) (defaults to: nil)

    Profile icon URL (optional)

  • inherit_contacts (Boolean, nil) (defaults to: nil)

    Whether this profile inherits contacts from organization (default: true)

  • inherit_tcr_brand (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR brand from organization (default: true)

  • inherit_tcr_campaign (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR campaign from organization (default: true)

  • inherit_templates (Boolean, nil) (defaults to: nil)

    Whether this profile inherits templates from organization (default: true)

  • name (String) (defaults to: nil)

    Profile name (required)

  • payment_details (Sentdm::Models::ProfileCreateParams::PaymentDetails, nil) (defaults to: nil)

    Payment card details for a profile.

  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects

  • short_name (String, nil) (defaults to: nil)

    Profile short name/abbreviation (optional). Must be 3–11 characters, contain onl

  • whatsapp_business_account (Sentdm::Models::ProfileCreateParams::WhatsappBusinessAccount, nil) (defaults to: nil)

    Direct WhatsApp Business Account credentials for a profile.

  • idempotency_key (String) (defaults to: nil)
  • x_profile_id (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/sentdm/models/profile_create_params.rb', line 177

class BillingContact < Sentdm::Internal::Type::BaseModel
  # @!attribute email
  #   Email address where invoices will be sent (required)
  #
  #   @return [String]
  required :email, String

  # @!attribute name
  #   Full name of the billing contact or company (required)
  #
  #   @return [String]
  required :name, String

  # @!attribute address
  #   Billing address (optional). Free-form text including street, city, state, postal
  #   code, and country.
  #
  #   @return [String, nil]
  optional :address, String, nil?: true

  # @!attribute phone
  #   Phone number for the billing contact (optional)
  #
  #   @return [String, nil]
  optional :phone, String, nil?: true

  # @!method initialize(email:, name:, address: nil, phone: nil)
  #   Some parameter documentations has been truncated, see
  #   {Sentdm::Models::ProfileCreateParams::BillingContact} for more details.
  #
  #   Billing contact information for a profile. Required when billing_model is
  #   "profile" or "profile_and_organization".
  #
  #   @param email [String] Email address where invoices will be sent (required)
  #
  #   @param name [String] Full name of the billing contact or company (required)
  #
  #   @param address [String, nil] Billing address (optional). Free-form text including street, city, state, postal
  #
  #   @param phone [String, nil] Phone number for the billing contact (optional)
end

Instance Attribute Details

#addressString?

Billing address (optional). Free-form text including street, city, state, postal code, and country.

Returns:

  • (String, nil)


195
# File 'lib/sentdm/models/profile_create_params.rb', line 195

optional :address, String, nil?: true

#emailString

Email address where invoices will be sent (required)

Returns:

  • (String)


182
# File 'lib/sentdm/models/profile_create_params.rb', line 182

required :email, String

#nameString

Full name of the billing contact or company (required)

Returns:

  • (String)


188
# File 'lib/sentdm/models/profile_create_params.rb', line 188

required :name, String

#phoneString?

Phone number for the billing contact (optional)

Returns:

  • (String, nil)


201
# File 'lib/sentdm/models/profile_create_params.rb', line 201

optional :phone, String, nil?: true