Class: Sentdm::Models::ProfileCreateParams::WhatsappBusinessAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/profile_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_token:, waba_id:, phone_number_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ProfileCreateParams::WhatsappBusinessAccount for more details.

Direct WhatsApp Business Account credentials for a profile. Use this when the profile should have its own WhatsApp Business Account instead of inheriting from the organization. Credentials must be obtained from Meta Business Manager by creating a System User with whatsapp_business_messaging and whatsapp_business_management scopes.

Parameters:

  • access_token (String)

    System User access token with whatsapp_business_messaging and

  • waba_id (String)

    WhatsApp Business Account ID from Meta Business Manager

  • phone_number_id (String, nil) (defaults to: nil)

    Phone Number ID of an existing number already registered under this WABA in Meta



# File 'lib/sentdm/models/profile_create_params.rb', line 615

Instance Attribute Details

#access_tokenString

System User access token with whatsapp_business_messaging and whatsapp_business_management permissions. This value is stored securely and never returned in API responses.

Returns:

  • (String)


598
# File 'lib/sentdm/models/profile_create_params.rb', line 598

required :access_token, String

#phone_number_idString?

Phone Number ID of an existing number already registered under this WABA in Meta Business Manager. Optional — when omitted, a number will be provisioned from our pool and registered in the WABA during the onboarding flow. When provided, the number must already exist in the WABA.

Returns:

  • (String, nil)


613
# File 'lib/sentdm/models/profile_create_params.rb', line 613

optional :phone_number_id, String, nil?: true

#waba_idString

WhatsApp Business Account ID from Meta Business Manager

Returns:

  • (String)


604
# File 'lib/sentdm/models/profile_create_params.rb', line 604

required :waba_id, String