Class: Sentdm::Models::ProfileListResponse::Data::Profile::Brand
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileListResponse::Data::Profile::Brand
- Defined in:
- lib/sentdm/models/profile_list_response.rb
Overview
Defined Under Namespace
Modules: IdentityStatus, Status Classes: Business, Compliance, Contact
Instance Attribute Summary collapse
-
#business ⇒ Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Business?
Business details and address information.
-
#compliance ⇒ Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Compliance?
Compliance and TCR-related information.
-
#contact ⇒ Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Contact?
Contact information for the brand.
-
#created_at ⇒ Time?
When the brand was created.
-
#csp_id ⇒ String?
CSP (Campaign Service Provider) ID.
-
#id ⇒ String?
Unique identifier for the brand.
- #identity_status ⇒ Symbol, ...
-
#is_inherited ⇒ Boolean?
Whether this brand is inherited from the parent organization.
- #status ⇒ Symbol, ...
-
#submitted_at ⇒ Time?
When the brand was submitted to TCR.
-
#submitted_to_tcr ⇒ Boolean?
Whether this brand has been submitted to TCR.
-
#tcr_brand_id ⇒ String?
TCR brand ID (populated after TCR submission).
-
#universal_ein ⇒ String?
Universal EIN from TCR.
-
#updated_at ⇒ Time?
When the brand was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(business_name: nil, email: nil, name: nil, phone: nil, phone_country_code: nil, role: nil) ⇒ Object
constructor
Contact information for the brand.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business_name: nil, email: nil, name: nil, phone: nil, phone_country_code: nil, role: nil) ⇒ Object
Contact information for the brand
|
|
# File 'lib/sentdm/models/profile_list_response.rb', line 389
|
Instance Attribute Details
#business ⇒ Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Business?
Business details and address information
311 |
# File 'lib/sentdm/models/profile_list_response.rb', line 311 optional :business, -> { Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Business }, nil?: true |
#compliance ⇒ Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Compliance?
Compliance and TCR-related information
317 318 319 |
# File 'lib/sentdm/models/profile_list_response.rb', line 317 optional :compliance, -> { Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Compliance }, nil?: true |
#contact ⇒ Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Contact?
Contact information for the brand
325 |
# File 'lib/sentdm/models/profile_list_response.rb', line 325 optional :contact, -> { Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Contact }, nil?: true |
#created_at ⇒ Time?
When the brand was created
331 |
# File 'lib/sentdm/models/profile_list_response.rb', line 331 optional :created_at, Time |
#csp_id ⇒ String?
CSP (Campaign Service Provider) ID
337 |
# File 'lib/sentdm/models/profile_list_response.rb', line 337 optional :csp_id, String, nil?: true |
#id ⇒ String?
Unique identifier for the brand
305 |
# File 'lib/sentdm/models/profile_list_response.rb', line 305 optional :id, String |
#identity_status ⇒ Symbol, ...
342 343 344 |
# File 'lib/sentdm/models/profile_list_response.rb', line 342 optional :identity_status, enum: -> { Sentdm::Models::ProfileListResponse::Data::Profile::Brand::IdentityStatus }, nil?: true |
#is_inherited ⇒ Boolean?
Whether this brand is inherited from the parent organization
350 |
# File 'lib/sentdm/models/profile_list_response.rb', line 350 optional :is_inherited, Sentdm::Internal::Type::Boolean |
#status ⇒ Symbol, ...
355 356 357 |
# File 'lib/sentdm/models/profile_list_response.rb', line 355 optional :status, enum: -> { Sentdm::Models::ProfileListResponse::Data::Profile::Brand::Status }, nil?: true |
#submitted_at ⇒ Time?
When the brand was submitted to TCR
363 |
# File 'lib/sentdm/models/profile_list_response.rb', line 363 optional :submitted_at, Time, nil?: true |
#submitted_to_tcr ⇒ Boolean?
Whether this brand has been submitted to TCR
369 |
# File 'lib/sentdm/models/profile_list_response.rb', line 369 optional :submitted_to_tcr, Sentdm::Internal::Type::Boolean |
#tcr_brand_id ⇒ String?
TCR brand ID (populated after TCR submission)
375 |
# File 'lib/sentdm/models/profile_list_response.rb', line 375 optional :tcr_brand_id, String, nil?: true |
#universal_ein ⇒ String?
Universal EIN from TCR
381 |
# File 'lib/sentdm/models/profile_list_response.rb', line 381 optional :universal_ein, String, nil?: true |
#updated_at ⇒ Time?
When the brand was last updated
387 |
# File 'lib/sentdm/models/profile_list_response.rb', line 387 optional :updated_at, Time, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/sentdm/models/profile_list_response.rb', line 645
|