Class: Sentdm::Models::ProfileSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/profile_settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allow_contact_sharing: nil, allow_template_sharing: nil, billing_model: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil) ⇒ Object

Profile configuration settings

Parameters:

  • allow_contact_sharing (Boolean, nil) (defaults to: nil)

    Whether contacts are shared across profiles in the organization

  • allow_template_sharing (Boolean, nil) (defaults to: nil)

    Whether templates are shared across profiles in the organization

  • billing_model (String, nil) (defaults to: nil)

    Billing model: profile, organization, or profile_and_organization

  • inherit_contacts (Boolean, nil) (defaults to: nil)

    Whether this profile inherits contacts from the organization

  • inherit_tcr_brand (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR brand from the organization

  • inherit_tcr_campaign (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR campaign from the organization

  • inherit_templates (Boolean, nil) (defaults to: nil)

    Whether this profile inherits templates from the organization



# File 'lib/sentdm/models/profile_settings.rb', line 48

Instance Attribute Details

#allow_contact_sharingBoolean?

Whether contacts are shared across profiles in the organization

Returns:

  • (Boolean, nil)


10
# File 'lib/sentdm/models/profile_settings.rb', line 10

optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#allow_template_sharingBoolean?

Whether templates are shared across profiles in the organization

Returns:

  • (Boolean, nil)


16
# File 'lib/sentdm/models/profile_settings.rb', line 16

optional :allow_template_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#billing_modelString?

Billing model: profile, organization, or profile_and_organization

Returns:

  • (String, nil)


22
# File 'lib/sentdm/models/profile_settings.rb', line 22

optional :billing_model, String, nil?: true

#inherit_contactsBoolean?

Whether this profile inherits contacts from the organization

Returns:

  • (Boolean, nil)


28
# File 'lib/sentdm/models/profile_settings.rb', line 28

optional :inherit_contacts, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_brandBoolean?

Whether this profile inherits TCR brand from the organization

Returns:

  • (Boolean, nil)


34
# File 'lib/sentdm/models/profile_settings.rb', line 34

optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_campaignBoolean?

Whether this profile inherits TCR campaign from the organization

Returns:

  • (Boolean, nil)


40
# File 'lib/sentdm/models/profile_settings.rb', line 40

optional :inherit_tcr_campaign, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_templatesBoolean?

Whether this profile inherits templates from the organization

Returns:

  • (Boolean, nil)


46
# File 'lib/sentdm/models/profile_settings.rb', line 46

optional :inherit_templates, Sentdm::Internal::Type::Boolean, nil?: true