Class: Sentdm::Models::ProfileUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/profile_update_params.rb

Overview

Defined Under Namespace

Classes: BillingContact, Brand, PaymentDetails

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, name:, address: nil, phone: nil) ⇒ Object

Some parameter documentations has been truncated, see BillingContact for more details.

Billing contact information for a profile. Required when billing_model is “profile” or “profile_and_organization”.

Parameters:

  • email (String)

    Email address where invoices will be sent (required)

  • name (String)

    Full name of the billing contact or company (required)

  • address (String, nil) (defaults to: nil)

    Billing address (optional). Free-form text including street, city, state, postal

  • phone (String, nil) (defaults to: nil)

    Phone number for the billing contact (optional)



# File 'lib/sentdm/models/profile_update_params.rb', line 235

Instance Attribute Details

#allow_contact_sharingBoolean?

Whether contacts are shared across profiles (optional)

Returns:

  • (Boolean, nil)


19
# File 'lib/sentdm/models/profile_update_params.rb', line 19

optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#allow_number_change_during_onboardingBoolean?

Whether number changes are allowed during onboarding (optional)

Returns:

  • (Boolean, nil)


25
# File 'lib/sentdm/models/profile_update_params.rb', line 25

optional :allow_number_change_during_onboarding, Sentdm::Internal::Type::Boolean, nil?: true

#allow_template_sharingBoolean?

Whether templates are shared across profiles (optional)

Returns:

  • (Boolean, nil)


31
# File 'lib/sentdm/models/profile_update_params.rb', line 31

optional :allow_template_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#billing_contactSentdm::Models::ProfileUpdateParams::BillingContact?

Billing contact information for a profile. Required when billing_model is “profile” or “profile_and_organization”.



38
# File 'lib/sentdm/models/profile_update_params.rb', line 38

optional :billing_contact, -> { Sentdm::ProfileUpdateParams::BillingContact }, nil?: true

#billing_modelString?

Billing model: profile, organization, or profile_and_organization (optional).

  • “organization”: the organization’s billing details are used; no profile-level billing info needed.

  • “profile”: the profile is billed independently; billing_contact is required.

  • “profile_and_organization”: the profile is billed first with the organization as fallback; billing_contact is required.

Returns:

  • (String, nil)


50
# File 'lib/sentdm/models/profile_update_params.rb', line 50

optional :billing_model, String, nil?: true

#brandSentdm::Models::ProfileUpdateParams::Brand?

Brand and KYC data grouped into contact, business, and compliance sections



56
# File 'lib/sentdm/models/profile_update_params.rb', line 56

optional :brand, -> { Sentdm::ProfileUpdateParams::Brand }, nil?: true

#descriptionString?

Profile description (optional)

Returns:

  • (String, nil)


62
# File 'lib/sentdm/models/profile_update_params.rb', line 62

optional :description, String, nil?: true

#iconString?

Profile icon URL (optional)

Returns:

  • (String, nil)


68
# File 'lib/sentdm/models/profile_update_params.rb', line 68

optional :icon, String, nil?: true

#idempotency_keyString?

Returns:

  • (String, nil)


150
# File 'lib/sentdm/models/profile_update_params.rb', line 150

optional :idempotency_key, String

#inherit_contactsBoolean?

Whether this profile inherits contacts from organization (optional)

Returns:

  • (Boolean, nil)


74
# File 'lib/sentdm/models/profile_update_params.rb', line 74

optional :inherit_contacts, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_brandBoolean?

Whether this profile inherits TCR brand from organization (optional)

Returns:

  • (Boolean, nil)


80
# File 'lib/sentdm/models/profile_update_params.rb', line 80

optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_campaignBoolean?

Whether this profile inherits TCR campaign from organization (optional)

Returns:

  • (Boolean, nil)


86
# File 'lib/sentdm/models/profile_update_params.rb', line 86

optional :inherit_tcr_campaign, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_templatesBoolean?

Whether this profile inherits templates from organization (optional)

Returns:

  • (Boolean, nil)


92
# File 'lib/sentdm/models/profile_update_params.rb', line 92

optional :inherit_templates, Sentdm::Internal::Type::Boolean, nil?: true

#nameString?

Profile name (optional)

Returns:

  • (String, nil)


98
# File 'lib/sentdm/models/profile_update_params.rb', line 98

optional :name, String, nil?: true

#payment_detailsSentdm::Models::ProfileUpdateParams::PaymentDetails?

Payment card details for a profile. Accepted when billing_model is “profile” or “profile_and_organization”. These details are not stored on our servers and will be forwarded to the payment processor.



106
# File 'lib/sentdm/models/profile_update_params.rb', line 106

optional :payment_details, -> { Sentdm::ProfileUpdateParams::PaymentDetails }, nil?: true

#profile_idString

Returns:

  • (String)


13
# File 'lib/sentdm/models/profile_update_params.rb', line 13

required :profile_id, String

#sandboxBoolean?

Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


113
# File 'lib/sentdm/models/profile_update_params.rb', line 113

optional :sandbox, Sentdm::Internal::Type::Boolean

#sending_phone_numberString?

Direct phone number for SMS sending (optional)

Returns:

  • (String, nil)


119
# File 'lib/sentdm/models/profile_update_params.rb', line 119

optional :sending_phone_number, String, nil?: true

#sending_phone_number_profile_idString?

Reference to another profile to use for SMS/Telnyx configuration (optional)

Returns:

  • (String, nil)


125
# File 'lib/sentdm/models/profile_update_params.rb', line 125

optional :sending_phone_number_profile_id, String, nil?: true

#sending_whatsapp_number_profile_idString?

Reference to another profile to use for WhatsApp configuration (optional)

Returns:

  • (String, nil)


131
# File 'lib/sentdm/models/profile_update_params.rb', line 131

optional :sending_whatsapp_number_profile_id, String, nil?: true

#short_nameString?

Profile short name/abbreviation (optional). Must be 3–11 characters, contain only letters, numbers, and spaces, and include at least one letter. Example: “SALES”, “Mkt 2”, “Support1”.

Returns:

  • (String, nil)


139
# File 'lib/sentdm/models/profile_update_params.rb', line 139

optional :short_name, String, nil?: true

#whatsapp_phone_numberString?

Direct phone number for WhatsApp sending (optional)

Returns:

  • (String, nil)


145
# File 'lib/sentdm/models/profile_update_params.rb', line 145

optional :whatsapp_phone_number, String, nil?: true

#x_profile_idString?

Returns:

  • (String, nil)


155
# File 'lib/sentdm/models/profile_update_params.rb', line 155

optional :x_profile_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/sentdm/models/profile_update_params.rb', line 578