Class: Sentdm::Models::ProfileUpdateParams::BillingContact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/profile_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(profile_id:, allow_contact_sharing: nil, allow_number_change_during_onboarding: nil, allow_template_sharing: nil, billing_contact: nil, billing_model: nil, brand: nil, description: nil, icon: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, name: nil, payment_details: nil, sandbox: nil, sending_phone_number: nil, sending_phone_number_profile_id: nil, sending_whatsapp_number_profile_id: nil, short_name: nil, whatsapp_phone_number: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ProfileUpdateParams for more details.

Parameters:

  • profile_id (String)
  • allow_contact_sharing (Boolean, nil) (defaults to: nil)

    Whether contacts are shared across profiles (optional)

  • allow_number_change_during_onboarding (Boolean, nil) (defaults to: nil)

    Whether number changes are allowed during onboarding (optional)

  • allow_template_sharing (Boolean, nil) (defaults to: nil)

    Whether templates are shared across profiles (optional)

  • billing_contact (Sentdm::Models::ProfileUpdateParams::BillingContact, nil) (defaults to: nil)

    Billing contact information for a profile.

  • billing_model (String, nil) (defaults to: nil)

    Billing model: profile, organization, or profile_and_organization (optional).

  • brand (Sentdm::Models::ProfileUpdateParams::Brand, nil) (defaults to: nil)

    Brand and KYC data grouped into contact, business, and compliance sections

  • description (String, nil) (defaults to: nil)

    Profile description (optional)

  • icon (String, nil) (defaults to: nil)

    Profile icon URL (optional)

  • inherit_contacts (Boolean, nil) (defaults to: nil)

    Whether this profile inherits contacts from organization (optional)

  • inherit_tcr_brand (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR brand from organization (optional)

  • inherit_tcr_campaign (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR campaign from organization (optional)

  • inherit_templates (Boolean, nil) (defaults to: nil)

    Whether this profile inherits templates from organization (optional)

  • name (String, nil) (defaults to: nil)

    Profile name (optional)

  • payment_details (Sentdm::Models::ProfileUpdateParams::PaymentDetails, nil) (defaults to: nil)

    Payment card details for a profile.

  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects

  • sending_phone_number (String, nil) (defaults to: nil)

    Direct phone number for SMS sending (optional)

  • sending_phone_number_profile_id (String, nil) (defaults to: nil)

    Reference to another profile to use for SMS/Telnyx configuration (optional)

  • sending_whatsapp_number_profile_id (String, nil) (defaults to: nil)

    Reference to another profile to use for WhatsApp configuration (optional)

  • short_name (String, nil) (defaults to: nil)

    Profile short name/abbreviation (optional). Must be 3–11 characters, contain onl

  • whatsapp_phone_number (String, nil) (defaults to: nil)

    Direct phone number for WhatsApp sending (optional)

  • idempotency_key (String) (defaults to: nil)
  • x_profile_id (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/sentdm/models/profile_update_params.rb', line 209

class BillingContact < Sentdm::Internal::Type::BaseModel
  # @!attribute email
  #   Email address where invoices will be sent (required)
  #
  #   @return [String]
  required :email, String

  # @!attribute name
  #   Full name of the billing contact or company (required)
  #
  #   @return [String]
  required :name, String

  # @!attribute address
  #   Billing address (optional). Free-form text including street, city, state, postal
  #   code, and country.
  #
  #   @return [String, nil]
  optional :address, String, nil?: true

  # @!attribute phone
  #   Phone number for the billing contact (optional)
  #
  #   @return [String, nil]
  optional :phone, String, nil?: true

  # @!method initialize(email:, name:, address: nil, phone: nil)
  #   Some parameter documentations has been truncated, see
  #   {Sentdm::Models::ProfileUpdateParams::BillingContact} for more details.
  #
  #   Billing contact information for a profile. Required when billing_model is
  #   "profile" or "profile_and_organization".
  #
  #   @param email [String] Email address where invoices will be sent (required)
  #
  #   @param name [String] Full name of the billing contact or company (required)
  #
  #   @param address [String, nil] Billing address (optional). Free-form text including street, city, state, postal
  #
  #   @param phone [String, nil] Phone number for the billing contact (optional)
end

Instance Attribute Details

#addressString?

Billing address (optional). Free-form text including street, city, state, postal code, and country.

Returns:

  • (String, nil)


227
# File 'lib/sentdm/models/profile_update_params.rb', line 227

optional :address, String, nil?: true

#emailString

Email address where invoices will be sent (required)

Returns:

  • (String)


214
# File 'lib/sentdm/models/profile_update_params.rb', line 214

required :email, String

#nameString

Full name of the billing contact or company (required)

Returns:

  • (String)


220
# File 'lib/sentdm/models/profile_update_params.rb', line 220

required :name, String

#phoneString?

Phone number for the billing contact (optional)

Returns:

  • (String, nil)


233
# File 'lib/sentdm/models/profile_update_params.rb', line 233

optional :phone, String, nil?: true