Class: Sentdm::Models::ProfileUpdateResponse::Data::Brand
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileUpdateResponse::Data::Brand
- Defined in:
- lib/sentdm/models/profile_update_response.rb
Overview
Defined Under Namespace
Modules: IdentityStatus, Status Classes: Business, Compliance, Contact
Instance Attribute Summary collapse
-
#business ⇒ Sentdm::Models::ProfileUpdateResponse::Data::Brand::Business?
Business details and address information.
-
#compliance ⇒ Sentdm::Models::ProfileUpdateResponse::Data::Brand::Compliance?
Compliance and TCR-related information.
-
#contact ⇒ Sentdm::Models::ProfileUpdateResponse::Data::Brand::Contact?
Contact information for the brand.
-
#created_at ⇒ Time?
When the brand was created.
-
#csp_id ⇒ String?
CSP (Campaign Service Provider) ID.
-
#id ⇒ String?
Unique identifier for the brand.
- #identity_status ⇒ Symbol, ...
-
#is_inherited ⇒ Boolean?
Whether this brand is inherited from the parent organization.
- #status ⇒ Symbol, ...
-
#submitted_at ⇒ Time?
When the brand was submitted to TCR.
-
#submitted_to_tcr ⇒ Boolean?
Whether this brand has been submitted to TCR.
-
#tcr_brand_id ⇒ String?
TCR brand ID (populated after TCR submission).
-
#universal_ein ⇒ String?
Universal EIN from TCR.
-
#updated_at ⇒ Time?
When the brand was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(business_name: nil, email: nil, name: nil, phone: nil, phone_country_code: nil, role: nil) ⇒ Object
constructor
Contact information for the brand.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business_name: nil, email: nil, name: nil, phone: nil, phone_country_code: nil, role: nil) ⇒ Object
Contact information for the brand
|
|
# File 'lib/sentdm/models/profile_update_response.rb', line 370
|
Instance Attribute Details
#business ⇒ Sentdm::Models::ProfileUpdateResponse::Data::Brand::Business?
Business details and address information
296 |
# File 'lib/sentdm/models/profile_update_response.rb', line 296 optional :business, -> { Sentdm::Models::ProfileUpdateResponse::Data::Brand::Business }, nil?: true |
#compliance ⇒ Sentdm::Models::ProfileUpdateResponse::Data::Brand::Compliance?
Compliance and TCR-related information
302 |
# File 'lib/sentdm/models/profile_update_response.rb', line 302 optional :compliance, -> { Sentdm::Models::ProfileUpdateResponse::Data::Brand::Compliance }, nil?: true |
#contact ⇒ Sentdm::Models::ProfileUpdateResponse::Data::Brand::Contact?
Contact information for the brand
308 |
# File 'lib/sentdm/models/profile_update_response.rb', line 308 optional :contact, -> { Sentdm::Models::ProfileUpdateResponse::Data::Brand::Contact }, nil?: true |
#created_at ⇒ Time?
When the brand was created
314 |
# File 'lib/sentdm/models/profile_update_response.rb', line 314 optional :created_at, Time |
#csp_id ⇒ String?
CSP (Campaign Service Provider) ID
320 |
# File 'lib/sentdm/models/profile_update_response.rb', line 320 optional :csp_id, String, nil?: true |
#id ⇒ String?
Unique identifier for the brand
290 |
# File 'lib/sentdm/models/profile_update_response.rb', line 290 optional :id, String |
#identity_status ⇒ Symbol, ...
325 326 327 |
# File 'lib/sentdm/models/profile_update_response.rb', line 325 optional :identity_status, enum: -> { Sentdm::Models::ProfileUpdateResponse::Data::Brand::IdentityStatus }, nil?: true |
#is_inherited ⇒ Boolean?
Whether this brand is inherited from the parent organization
333 |
# File 'lib/sentdm/models/profile_update_response.rb', line 333 optional :is_inherited, Sentdm::Internal::Type::Boolean |
#status ⇒ Symbol, ...
338 |
# File 'lib/sentdm/models/profile_update_response.rb', line 338 optional :status, enum: -> { Sentdm::Models::ProfileUpdateResponse::Data::Brand::Status }, nil?: true |
#submitted_at ⇒ Time?
When the brand was submitted to TCR
344 |
# File 'lib/sentdm/models/profile_update_response.rb', line 344 optional :submitted_at, Time, nil?: true |
#submitted_to_tcr ⇒ Boolean?
Whether this brand has been submitted to TCR
350 |
# File 'lib/sentdm/models/profile_update_response.rb', line 350 optional :submitted_to_tcr, Sentdm::Internal::Type::Boolean |
#tcr_brand_id ⇒ String?
TCR brand ID (populated after TCR submission)
356 |
# File 'lib/sentdm/models/profile_update_response.rb', line 356 optional :tcr_brand_id, String, nil?: true |
#universal_ein ⇒ String?
Universal EIN from TCR
362 |
# File 'lib/sentdm/models/profile_update_response.rb', line 362 optional :universal_ein, String, nil?: true |
#updated_at ⇒ Time?
When the brand was last updated
368 |
# File 'lib/sentdm/models/profile_update_response.rb', line 368 optional :updated_at, Time, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/sentdm/models/profile_update_response.rb', line 626
|