Class: Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateHeader

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sentdm/models/sent_dm_services_common_contracts_poc_os_template_header.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(template:, type: nil, variables: nil) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateHeader for more details.

Header section of a message template

Parameters:

  • template (String)

    The header template text with optional variable placeholders (e.g., “Welcome to

  • type (String, nil) (defaults to: nil)

    The type of header (e.g., “text”, “image”, “video”, “document”)

  • variables (Array<Sentdm::Models::TemplateVariable>, nil) (defaults to: nil)

    List of variables used in the header template



# File 'lib/sentdm/models/sent_dm_services_common_contracts_poc_os_template_header.rb', line 25

Instance Attribute Details

#templateString

The header template text with optional variable placeholders (e.g., “Welcome to {0:variable}”)

Returns:

  • (String)


11
# File 'lib/sentdm/models/sent_dm_services_common_contracts_poc_os_template_header.rb', line 11

required :template, String

#typeString?

The type of header (e.g., “text”, “image”, “video”, “document”)

Returns:

  • (String, nil)


17
# File 'lib/sentdm/models/sent_dm_services_common_contracts_poc_os_template_header.rb', line 17

optional :type, String, nil?: true

#variablesArray<Sentdm::Models::TemplateVariable>?

List of variables used in the header template

Returns:



23
# File 'lib/sentdm/models/sent_dm_services_common_contracts_poc_os_template_header.rb', line 23

optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateVariable] }, nil?: true