Class: Sentdm::Models::TemplateCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/template_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(category: nil, creation_source: nil, definition: nil, language: nil, sandbox: nil, submit_for_review: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::TemplateCreateParams for more details.

Parameters:

  • category (String, nil) (defaults to: nil)

    Template category: MARKETING, UTILITY, AUTHENTICATION (optional, auto-detected i

  • creation_source (String, nil) (defaults to: nil)

    Source of template creation (default: from-api)

  • definition (Sentdm::Models::TemplateDefinition) (defaults to: nil)

    Complete definition of a message template including header, body, footer, and bu

  • language (String, nil) (defaults to: nil)

    Template language code (e.g., en_US) (optional, auto-detected if not provided)

  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects

  • submit_for_review (Boolean) (defaults to: nil)

    Whether to submit the template for review after creation (default: false)

  • idempotency_key (String) (defaults to: nil)
  • x_profile_id (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/template_create_params.rb', line 59

Instance Attribute Details

#categoryString?

Template category: MARKETING, UTILITY, AUTHENTICATION (optional, auto-detected if not provided)

Returns:

  • (String, nil)


15
# File 'lib/sentdm/models/template_create_params.rb', line 15

optional :category, String, nil?: true

#creation_sourceString?

Source of template creation (default: from-api)

Returns:

  • (String, nil)


21
# File 'lib/sentdm/models/template_create_params.rb', line 21

optional :creation_source, String, nil?: true

#definitionSentdm::Models::TemplateDefinition?

Complete definition of a message template including header, body, footer, and buttons



28
# File 'lib/sentdm/models/template_create_params.rb', line 28

optional :definition, -> { Sentdm::TemplateDefinition }

#idempotency_keyString?

Returns:

  • (String, nil)


52
# File 'lib/sentdm/models/template_create_params.rb', line 52

optional :idempotency_key, String

#languageString?

Template language code (e.g., en_US) (optional, auto-detected if not provided)

Returns:

  • (String, nil)


34
# File 'lib/sentdm/models/template_create_params.rb', line 34

optional :language, String, nil?: true

#sandboxBoolean?

Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


41
# File 'lib/sentdm/models/template_create_params.rb', line 41

optional :sandbox, Sentdm::Internal::Type::Boolean

#submit_for_reviewBoolean?

Whether to submit the template for review after creation (default: false)

Returns:

  • (Boolean, nil)


47
# File 'lib/sentdm/models/template_create_params.rb', line 47

optional :submit_for_review, Sentdm::Internal::Type::Boolean

#x_profile_idString?

Returns:

  • (String, nil)


57
# File 'lib/sentdm/models/template_create_params.rb', line 57

optional :x_profile_id, String