Class: Sentdm::Models::TemplateCreateParams::Definition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::TemplateCreateParams::Definition
- Defined in:
- lib/sentdm/models/template_create_params.rb
Defined Under Namespace
Classes: AuthenticationConfig, Body, Button, Footer, Header
Instance Attribute Summary collapse
-
#authentication_config ⇒ Sentdm::Models::TemplateCreateParams::Definition::AuthenticationConfig?
Configuration for AUTHENTICATION category templates.
-
#body ⇒ Sentdm::Models::TemplateCreateParams::Definition::Body
Body section of a message template with channel-specific content.
-
#buttons ⇒ Array<Sentdm::Models::TemplateCreateParams::Definition::Button>?
Optional list of interactive buttons (e.g., quick replies, URLs, phone numbers).
-
#definition_version ⇒ String?
The version of the template definition format.
-
#footer ⇒ Sentdm::Models::TemplateCreateParams::Definition::Footer?
Footer section of a message template.
-
#header ⇒ Sentdm::Models::TemplateCreateParams::Definition::Header?
Header section of a message template.
Instance Method Summary collapse
- #initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) ⇒ Object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'lib/sentdm/models/template_create_params.rb', line 81 class Definition < Sentdm::Internal::Type::BaseModel # @!attribute body # Body section of a message template with channel-specific content # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body] required :body, -> { Sentdm::TemplateCreateParams::Definition::Body } # @!attribute authentication_config # Configuration for AUTHENTICATION category templates # # @return [Sentdm::Models::TemplateCreateParams::Definition::AuthenticationConfig, nil] optional :authentication_config, -> { Sentdm::TemplateCreateParams::Definition::AuthenticationConfig }, api_name: :authenticationConfig, nil?: true # @!attribute buttons # Optional list of interactive buttons (e.g., quick replies, URLs, phone numbers) # # @return [Array<Sentdm::Models::TemplateCreateParams::Definition::Button>, nil] optional :buttons, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Button] }, nil?: true # @!attribute definition_version # The version of the template definition format # # @return [String, nil] optional :definition_version, String, api_name: :definitionVersion, nil?: true # @!attribute footer # Footer section of a message template # # @return [Sentdm::Models::TemplateCreateParams::Definition::Footer, nil] optional :footer, -> { Sentdm::TemplateCreateParams::Definition::Footer }, nil?: true # @!attribute header # Header section of a message template # # @return [Sentdm::Models::TemplateCreateParams::Definition::Header, nil] optional :header, -> { Sentdm::TemplateCreateParams::Definition::Header }, nil?: true # @!method initialize(body:, authentication_config: nil, buttons: nil, definition_version: nil, footer: nil, header: nil) # Complete definition of a message template including header, body, footer, and # buttons # # @param body [Sentdm::Models::TemplateCreateParams::Definition::Body] Body section of a message template with channel-specific content # # @param authentication_config [Sentdm::Models::TemplateCreateParams::Definition::AuthenticationConfig, nil] Configuration for AUTHENTICATION category templates # # @param buttons [Array<Sentdm::Models::TemplateCreateParams::Definition::Button>, nil] Optional list of interactive buttons (e.g., quick replies, URLs, phone numbers) # # @param definition_version [String, nil] The version of the template definition format # # @param footer [Sentdm::Models::TemplateCreateParams::Definition::Footer, nil] Footer section of a message template # # @param header [Sentdm::Models::TemplateCreateParams::Definition::Header, nil] Header section of a message template # @see Sentdm::Models::TemplateCreateParams::Definition#body class Body < Sentdm::Internal::Type::BaseModel # @!attribute multi_channel # Content that will be used for all channels (SMS and WhatsApp) unless # channel-specific content is provided # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::MultiChannel, nil] optional :multi_channel, -> { Sentdm::TemplateCreateParams::Definition::Body::MultiChannel }, api_name: :multiChannel, nil?: true # @!attribute rcs # RCS-specific content that overrides multi-channel content for RCS messages # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::Rcs, nil] optional :rcs, -> { Sentdm::TemplateCreateParams::Definition::Body::Rcs }, nil?: true # @!attribute sms # SMS-specific content that overrides multi-channel content for SMS messages # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::SMS, nil] optional :sms, -> { Sentdm::TemplateCreateParams::Definition::Body::SMS }, nil?: true # @!attribute whatsapp # WhatsApp-specific content that overrides multi-channel content for WhatsApp # messages # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::Whatsapp, nil] optional :whatsapp, -> { Sentdm::TemplateCreateParams::Definition::Body::Whatsapp }, nil?: true # @!method initialize(multi_channel: nil, rcs: nil, sms: nil, whatsapp: nil) # Some parameter documentations has been truncated, see # {Sentdm::Models::TemplateCreateParams::Definition::Body} for more details. # # Body section of a message template with channel-specific content # # @param multi_channel [Sentdm::Models::TemplateCreateParams::Definition::Body::MultiChannel, nil] Content that will be used for all channels (SMS and WhatsApp) unless channel-spe # # @param rcs [Sentdm::Models::TemplateCreateParams::Definition::Body::Rcs, nil] RCS-specific content that overrides multi-channel content for RCS messages # # @param sms [Sentdm::Models::TemplateCreateParams::Definition::Body::SMS, nil] SMS-specific content that overrides multi-channel content for SMS messages # # @param whatsapp [Sentdm::Models::TemplateCreateParams::Definition::Body::Whatsapp, nil] WhatsApp-specific content that overrides multi-channel content for WhatsApp mess # @see Sentdm::Models::TemplateCreateParams::Definition::Body#multi_channel class MultiChannel < Sentdm::Internal::Type::BaseModel # @!attribute template # # @return [String] required :template, String # @!attribute type # # @return [String, nil] optional :type, String, nil?: true # @!attribute variables # # @return [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::MultiChannel::Variable>, nil] optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Body::MultiChannel::Variable] }, nil?: true # @!method initialize(template:, type: nil, variables: nil) # Content that will be used for all channels (SMS and WhatsApp) unless # channel-specific content is provided # # @param template [String] # @param type [String, nil] # @param variables [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::MultiChannel::Variable>, nil] class Variable < Sentdm::Internal::Type::BaseModel # @!attribute name # # @return [String] required :name, String # @!attribute props # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::MultiChannel::Variable::Props] required :props, -> { Sentdm::TemplateCreateParams::Definition::Body::MultiChannel::Variable::Props } # @!attribute type # # @return [String] required :type, String # @!attribute id # # @return [Integer, nil] optional :id, Integer # @!method initialize(name:, props:, type:, id: nil) # @param name [String] # @param props [Sentdm::Models::TemplateCreateParams::Definition::Body::MultiChannel::Variable::Props] # @param type [String] # @param id [Integer] # @see Sentdm::Models::TemplateCreateParams::Definition::Body::MultiChannel::Variable#props class Props < Sentdm::Internal::Type::BaseModel # @!attribute media_type # # @return [String] required :media_type, String, api_name: :mediaType # @!attribute sample # # @return [String] required :sample, String # @!attribute url # # @return [String] required :url, String # @!attribute variable_type # # @return [String] required :variable_type, String, api_name: :variableType # @!attribute alt # # @return [String, nil] optional :alt, String, nil?: true # @!attribute regex # # @return [String, nil] optional :regex, String, nil?: true # @!attribute short_url # # @return [String, nil] optional :short_url, String, api_name: :shortUrl, nil?: true # @!method initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) # @param media_type [String] # @param sample [String] # @param url [String] # @param variable_type [String] # @param alt [String, nil] # @param regex [String, nil] # @param short_url [String, nil] end end end # @see Sentdm::Models::TemplateCreateParams::Definition::Body#rcs class Rcs < Sentdm::Internal::Type::BaseModel # @!attribute template # # @return [String] required :template, String # @!attribute type # # @return [String, nil] optional :type, String, nil?: true # @!attribute variables # # @return [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::Rcs::Variable>, nil] optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Body::Rcs::Variable] }, nil?: true # @!method initialize(template:, type: nil, variables: nil) # RCS-specific content that overrides multi-channel content for RCS messages # # @param template [String] # @param type [String, nil] # @param variables [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::Rcs::Variable>, nil] class Variable < Sentdm::Internal::Type::BaseModel # @!attribute name # # @return [String] required :name, String # @!attribute props # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::Rcs::Variable::Props] required :props, -> { Sentdm::TemplateCreateParams::Definition::Body::Rcs::Variable::Props } # @!attribute type # # @return [String] required :type, String # @!attribute id # # @return [Integer, nil] optional :id, Integer # @!method initialize(name:, props:, type:, id: nil) # @param name [String] # @param props [Sentdm::Models::TemplateCreateParams::Definition::Body::Rcs::Variable::Props] # @param type [String] # @param id [Integer] # @see Sentdm::Models::TemplateCreateParams::Definition::Body::Rcs::Variable#props class Props < Sentdm::Internal::Type::BaseModel # @!attribute media_type # # @return [String] required :media_type, String, api_name: :mediaType # @!attribute sample # # @return [String] required :sample, String # @!attribute url # # @return [String] required :url, String # @!attribute variable_type # # @return [String] required :variable_type, String, api_name: :variableType # @!attribute alt # # @return [String, nil] optional :alt, String, nil?: true # @!attribute regex # # @return [String, nil] optional :regex, String, nil?: true # @!attribute short_url # # @return [String, nil] optional :short_url, String, api_name: :shortUrl, nil?: true # @!method initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) # @param media_type [String] # @param sample [String] # @param url [String] # @param variable_type [String] # @param alt [String, nil] # @param regex [String, nil] # @param short_url [String, nil] end end end # @see Sentdm::Models::TemplateCreateParams::Definition::Body#sms class SMS < Sentdm::Internal::Type::BaseModel # @!attribute template # # @return [String] required :template, String # @!attribute type # # @return [String, nil] optional :type, String, nil?: true # @!attribute variables # # @return [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::SMS::Variable>, nil] optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Body::SMS::Variable] }, nil?: true # @!method initialize(template:, type: nil, variables: nil) # SMS-specific content that overrides multi-channel content for SMS messages # # @param template [String] # @param type [String, nil] # @param variables [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::SMS::Variable>, nil] class Variable < Sentdm::Internal::Type::BaseModel # @!attribute name # # @return [String] required :name, String # @!attribute props # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::SMS::Variable::Props] required :props, -> { Sentdm::TemplateCreateParams::Definition::Body::SMS::Variable::Props } # @!attribute type # # @return [String] required :type, String # @!attribute id # # @return [Integer, nil] optional :id, Integer # @!method initialize(name:, props:, type:, id: nil) # @param name [String] # @param props [Sentdm::Models::TemplateCreateParams::Definition::Body::SMS::Variable::Props] # @param type [String] # @param id [Integer] # @see Sentdm::Models::TemplateCreateParams::Definition::Body::SMS::Variable#props class Props < Sentdm::Internal::Type::BaseModel # @!attribute media_type # # @return [String] required :media_type, String, api_name: :mediaType # @!attribute sample # # @return [String] required :sample, String # @!attribute url # # @return [String] required :url, String # @!attribute variable_type # # @return [String] required :variable_type, String, api_name: :variableType # @!attribute alt # # @return [String, nil] optional :alt, String, nil?: true # @!attribute regex # # @return [String, nil] optional :regex, String, nil?: true # @!attribute short_url # # @return [String, nil] optional :short_url, String, api_name: :shortUrl, nil?: true # @!method initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) # @param media_type [String] # @param sample [String] # @param url [String] # @param variable_type [String] # @param alt [String, nil] # @param regex [String, nil] # @param short_url [String, nil] end end end # @see Sentdm::Models::TemplateCreateParams::Definition::Body#whatsapp class Whatsapp < Sentdm::Internal::Type::BaseModel # @!attribute template # # @return [String] required :template, String # @!attribute type # # @return [String, nil] optional :type, String, nil?: true # @!attribute variables # # @return [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::Whatsapp::Variable>, nil] optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Body::Whatsapp::Variable] }, nil?: true # @!method initialize(template:, type: nil, variables: nil) # WhatsApp-specific content that overrides multi-channel content for WhatsApp # messages # # @param template [String] # @param type [String, nil] # @param variables [Array<Sentdm::Models::TemplateCreateParams::Definition::Body::Whatsapp::Variable>, nil] class Variable < Sentdm::Internal::Type::BaseModel # @!attribute name # # @return [String] required :name, String # @!attribute props # # @return [Sentdm::Models::TemplateCreateParams::Definition::Body::Whatsapp::Variable::Props] required :props, -> { Sentdm::TemplateCreateParams::Definition::Body::Whatsapp::Variable::Props } # @!attribute type # # @return [String] required :type, String # @!attribute id # # @return [Integer, nil] optional :id, Integer # @!method initialize(name:, props:, type:, id: nil) # @param name [String] # @param props [Sentdm::Models::TemplateCreateParams::Definition::Body::Whatsapp::Variable::Props] # @param type [String] # @param id [Integer] # @see Sentdm::Models::TemplateCreateParams::Definition::Body::Whatsapp::Variable#props class Props < Sentdm::Internal::Type::BaseModel # @!attribute media_type # # @return [String] required :media_type, String, api_name: :mediaType # @!attribute sample # # @return [String] required :sample, String # @!attribute url # # @return [String] required :url, String # @!attribute variable_type # # @return [String] required :variable_type, String, api_name: :variableType # @!attribute alt # # @return [String, nil] optional :alt, String, nil?: true # @!attribute regex # # @return [String, nil] optional :regex, String, nil?: true # @!attribute short_url # # @return [String, nil] optional :short_url, String, api_name: :shortUrl, nil?: true # @!method initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) # @param media_type [String] # @param sample [String] # @param url [String] # @param variable_type [String] # @param alt [String, nil] # @param regex [String, nil] # @param short_url [String, nil] end end end end # @see Sentdm::Models::TemplateCreateParams::Definition#authentication_config class AuthenticationConfig < Sentdm::Internal::Type::BaseModel # @!attribute add_security_recommendation # Whether to add the security recommendation text: "For your security, do not # share this code." # # @return [Boolean, nil] optional :add_security_recommendation, Sentdm::Internal::Type::Boolean, api_name: :addSecurityRecommendation # @!attribute code_expiration_minutes # Code expiration time in minutes (1-90). If set, adds footer: "This code expires # in X minutes." # # @return [Integer, nil] optional :code_expiration_minutes, Integer, api_name: :codeExpirationMinutes, nil?: true # @!method initialize(add_security_recommendation: nil, code_expiration_minutes: nil) # Some parameter documentations has been truncated, see # {Sentdm::Models::TemplateCreateParams::Definition::AuthenticationConfig} for # more details. # # Configuration for AUTHENTICATION category templates # # @param add_security_recommendation [Boolean] Whether to add the security recommendation text: "For your security, do not shar # # @param code_expiration_minutes [Integer, nil] Code expiration time in minutes (1-90). If set, adds footer: "This code expires end class Button < Sentdm::Internal::Type::BaseModel # @!attribute props # Properties specific to the button type # # @return [Sentdm::Models::TemplateCreateParams::Definition::Button::Props] required :props, -> { Sentdm::TemplateCreateParams::Definition::Button::Props } # @!attribute type # The type of button (e.g., QUICK_REPLY, URL, PHONE_NUMBER, VOICE_CALL, COPY_CODE) # # @return [String] required :type, String # @!attribute id # The unique identifier of the button (1-based index) # # @return [Integer, nil] optional :id, Integer # @!method initialize(props:, type:, id: nil) # Some parameter documentations has been truncated, see # {Sentdm::Models::TemplateCreateParams::Definition::Button} for more details. # # Interactive button in a message template # # @param props [Sentdm::Models::TemplateCreateParams::Definition::Button::Props] Properties specific to the button type # # @param type [String] The type of button (e.g., QUICK_REPLY, URL, PHONE_NUMBER, VOICE_CALL, COPY_CODE) # # @param id [Integer] The unique identifier of the button (1-based index) # @see Sentdm::Models::TemplateCreateParams::Definition::Button#props class Props < Sentdm::Internal::Type::BaseModel # @!attribute active_for # # @return [Integer] required :active_for, Integer, api_name: :activeFor # @!attribute country_code # # @return [String] required :country_code, String, api_name: :countryCode # @!attribute offer_code # # @return [String] required :offer_code, String, api_name: :offerCode # @!attribute phone_number # # @return [String] required :phone_number, String, api_name: :phoneNumber # @!attribute quick_reply_type # # @return [String] required :quick_reply_type, String, api_name: :quickReplyType # @!attribute text # # @return [String] required :text, String # @!attribute url # # @return [String] required :url, String # @!attribute url_type # # @return [String] required :url_type, String, api_name: :urlType # @!attribute autofill_text # # @return [String, nil] optional :autofill_text, String, api_name: :autofillText, nil?: true # @!attribute otp_type # # @return [String, nil] optional :otp_type, String, api_name: :otpType, nil?: true # @!attribute package_name # # @return [String, nil] optional :package_name, String, api_name: :packageName, nil?: true # @!attribute signature_hash # # @return [String, nil] optional :signature_hash, String, api_name: :signatureHash, nil?: true # @!method initialize(active_for:, country_code:, offer_code:, phone_number:, quick_reply_type:, text:, url:, url_type:, autofill_text: nil, otp_type: nil, package_name: nil, signature_hash: nil) # Properties specific to the button type # # @param active_for [Integer] # @param country_code [String] # @param offer_code [String] # @param phone_number [String] # @param quick_reply_type [String] # @param text [String] # @param url [String] # @param url_type [String] # @param autofill_text [String, nil] # @param otp_type [String, nil] # @param package_name [String, nil] # @param signature_hash [String, nil] end end # @see Sentdm::Models::TemplateCreateParams::Definition#footer class Footer < Sentdm::Internal::Type::BaseModel # @!attribute template # The footer template text with optional variable placeholders # # @return [String] required :template, String # @!attribute type # The type of footer (typically "text") # # @return [String, nil] optional :type, String, nil?: true # @!attribute variables # List of variables used in the footer template # # @return [Array<Sentdm::Models::TemplateCreateParams::Definition::Footer::Variable>, nil] optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Footer::Variable] }, nil?: true # @!method initialize(template:, type: nil, variables: nil) # Footer section of a message template # # @param template [String] The footer template text with optional variable placeholders # # @param type [String, nil] The type of footer (typically "text") # # @param variables [Array<Sentdm::Models::TemplateCreateParams::Definition::Footer::Variable>, nil] List of variables used in the footer template class Variable < Sentdm::Internal::Type::BaseModel # @!attribute name # # @return [String] required :name, String # @!attribute props # # @return [Sentdm::Models::TemplateCreateParams::Definition::Footer::Variable::Props] required :props, -> { Sentdm::TemplateCreateParams::Definition::Footer::Variable::Props } # @!attribute type # # @return [String] required :type, String # @!attribute id # # @return [Integer, nil] optional :id, Integer # @!method initialize(name:, props:, type:, id: nil) # @param name [String] # @param props [Sentdm::Models::TemplateCreateParams::Definition::Footer::Variable::Props] # @param type [String] # @param id [Integer] # @see Sentdm::Models::TemplateCreateParams::Definition::Footer::Variable#props class Props < Sentdm::Internal::Type::BaseModel # @!attribute media_type # # @return [String] required :media_type, String, api_name: :mediaType # @!attribute sample # # @return [String] required :sample, String # @!attribute url # # @return [String] required :url, String # @!attribute variable_type # # @return [String] required :variable_type, String, api_name: :variableType # @!attribute alt # # @return [String, nil] optional :alt, String, nil?: true # @!attribute regex # # @return [String, nil] optional :regex, String, nil?: true # @!attribute short_url # # @return [String, nil] optional :short_url, String, api_name: :shortUrl, nil?: true # @!method initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) # @param media_type [String] # @param sample [String] # @param url [String] # @param variable_type [String] # @param alt [String, nil] # @param regex [String, nil] # @param short_url [String, nil] end end end # @see Sentdm::Models::TemplateCreateParams::Definition#header class Header < Sentdm::Internal::Type::BaseModel # @!attribute template # The header template text with optional variable placeholders (e.g., "Welcome to # {{0:variable}}") # # @return [String] required :template, String # @!attribute type # The type of header (e.g., "text", "image", "video", "document") # # @return [String, nil] optional :type, String, nil?: true # @!attribute variables # List of variables used in the header template # # @return [Array<Sentdm::Models::TemplateCreateParams::Definition::Header::Variable>, nil] optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Header::Variable] }, nil?: true # @!method initialize(template:, type: nil, variables: nil) # Some parameter documentations has been truncated, see # {Sentdm::Models::TemplateCreateParams::Definition::Header} for more details. # # Header section of a message template # # @param template [String] The header template text with optional variable placeholders (e.g., "Welcome to # # @param type [String, nil] The type of header (e.g., "text", "image", "video", "document") # # @param variables [Array<Sentdm::Models::TemplateCreateParams::Definition::Header::Variable>, nil] List of variables used in the header template class Variable < Sentdm::Internal::Type::BaseModel # @!attribute name # # @return [String] required :name, String # @!attribute props # # @return [Sentdm::Models::TemplateCreateParams::Definition::Header::Variable::Props] required :props, -> { Sentdm::TemplateCreateParams::Definition::Header::Variable::Props } # @!attribute type # # @return [String] required :type, String # @!attribute id # # @return [Integer, nil] optional :id, Integer # @!method initialize(name:, props:, type:, id: nil) # @param name [String] # @param props [Sentdm::Models::TemplateCreateParams::Definition::Header::Variable::Props] # @param type [String] # @param id [Integer] # @see Sentdm::Models::TemplateCreateParams::Definition::Header::Variable#props class Props < Sentdm::Internal::Type::BaseModel # @!attribute media_type # # @return [String] required :media_type, String, api_name: :mediaType # @!attribute sample # # @return [String] required :sample, String # @!attribute url # # @return [String] required :url, String # @!attribute variable_type # # @return [String] required :variable_type, String, api_name: :variableType # @!attribute alt # # @return [String, nil] optional :alt, String, nil?: true # @!attribute regex # # @return [String, nil] optional :regex, String, nil?: true # @!attribute short_url # # @return [String, nil] optional :short_url, String, api_name: :shortUrl, nil?: true # @!method initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) # @param media_type [String] # @param sample [String] # @param url [String] # @param variable_type [String] # @param alt [String, nil] # @param regex [String, nil] # @param short_url [String, nil] end end end end |
Instance Attribute Details
#authentication_config ⇒ Sentdm::Models::TemplateCreateParams::Definition::AuthenticationConfig?
Configuration for AUTHENTICATION category templates
92 93 94 95 |
# File 'lib/sentdm/models/template_create_params.rb', line 92 optional :authentication_config, -> { Sentdm::TemplateCreateParams::Definition::AuthenticationConfig }, api_name: :authenticationConfig, nil?: true |
#body ⇒ Sentdm::Models::TemplateCreateParams::Definition::Body
Body section of a message template with channel-specific content
86 |
# File 'lib/sentdm/models/template_create_params.rb', line 86 required :body, -> { Sentdm::TemplateCreateParams::Definition::Body } |
#buttons ⇒ Array<Sentdm::Models::TemplateCreateParams::Definition::Button>?
Optional list of interactive buttons (e.g., quick replies, URLs, phone numbers)
101 102 103 |
# File 'lib/sentdm/models/template_create_params.rb', line 101 optional :buttons, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Button] }, nil?: true |
#definition_version ⇒ String?
The version of the template definition format
109 |
# File 'lib/sentdm/models/template_create_params.rb', line 109 optional :definition_version, String, api_name: :definitionVersion, nil?: true |
#footer ⇒ Sentdm::Models::TemplateCreateParams::Definition::Footer?
Footer section of a message template
115 |
# File 'lib/sentdm/models/template_create_params.rb', line 115 optional :footer, -> { Sentdm::TemplateCreateParams::Definition::Footer }, nil?: true |
#header ⇒ Sentdm::Models::TemplateCreateParams::Definition::Header?
Header section of a message template
121 |
# File 'lib/sentdm/models/template_create_params.rb', line 121 optional :header, -> { Sentdm::TemplateCreateParams::Definition::Header }, nil?: true |