Class: Sentdm::Models::TemplateCreateParams::Definition::Header
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::TemplateCreateParams::Definition::Header
- Defined in:
- lib/sentdm/models/template_create_params.rb
Overview
Defined Under Namespace
Classes: Variable
Instance Attribute Summary collapse
-
#template ⇒ String
The header template text with optional variable placeholders (e.g., “Welcome to {0:variable}”).
-
#type ⇒ String?
The type of header (e.g., “text”, “image”, “video”, “document”).
-
#variables ⇒ Array<Sentdm::Models::TemplateCreateParams::Definition::Header::Variable>?
List of variables used in the header template.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Sentdm::Internal::Type::BaseModel
Instance Attribute Details
#template ⇒ String
The header template text with optional variable placeholders (e.g., “Welcome to {0:variable}”)
860 |
# File 'lib/sentdm/models/template_create_params.rb', line 860 required :template, String |
#type ⇒ String?
The type of header (e.g., “text”, “image”, “video”, “document”)
866 |
# File 'lib/sentdm/models/template_create_params.rb', line 866 optional :type, String, nil?: true |
#variables ⇒ Array<Sentdm::Models::TemplateCreateParams::Definition::Header::Variable>?
List of variables used in the header template
872 873 874 875 876 |
# File 'lib/sentdm/models/template_create_params.rb', line 872 optional :variables, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::TemplateCreateParams::Definition::Header::Variable] }, nil?: true |