Class: Sentdm::Models::TemplateDefinition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::TemplateDefinition
- Defined in:
- lib/sentdm/models/template_definition.rb
Instance Attribute Summary collapse
-
#authentication_config ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsAuthenticationConfig?
Configuration for AUTHENTICATION category templates.
-
#body ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateBody
Body section of a message template with channel-specific content.
-
#buttons ⇒ Array<Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateButton>?
Optional list of interactive buttons (e.g., quick replies, URLs, phone numbers).
-
#definition_version ⇒ String?
The version of the template definition format.
-
#footer ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateFooter?
Footer section of a message template.
-
#header ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateHeader?
Header section of a message template.
Instance Method Summary collapse
-
#initialize(body:, authentication_config: nil, buttons: nil, definition_version: nil, footer: nil, header: nil) ⇒ Object
constructor
Complete definition of a message template including header, body, footer, and buttons.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, authentication_config: nil, buttons: nil, definition_version: nil, footer: nil, header: nil) ⇒ Object
Complete definition of a message template including header, body, footer, and buttons
|
|
# File 'lib/sentdm/models/template_definition.rb', line 49
|
Instance Attribute Details
#authentication_config ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsAuthenticationConfig?
Configuration for AUTHENTICATION category templates
16 17 18 19 |
# File 'lib/sentdm/models/template_definition.rb', line 16 optional :authentication_config, -> { Sentdm::SentDmServicesCommonContractsPocOsAuthenticationConfig }, api_name: :authenticationConfig, nil?: true |
#body ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateBody
Body section of a message template with channel-specific content
10 |
# File 'lib/sentdm/models/template_definition.rb', line 10 required :body, -> { Sentdm::SentDmServicesCommonContractsPocOsTemplateBody } |
#buttons ⇒ Array<Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateButton>?
Optional list of interactive buttons (e.g., quick replies, URLs, phone numbers)
25 26 27 28 29 |
# File 'lib/sentdm/models/template_definition.rb', line 25 optional :buttons, -> { Sentdm::Internal::Type::ArrayOf[Sentdm::SentDmServicesCommonContractsPocOsTemplateButton] }, nil?: true |
#definition_version ⇒ String?
The version of the template definition format
35 |
# File 'lib/sentdm/models/template_definition.rb', line 35 optional :definition_version, String, api_name: :definitionVersion, nil?: true |
#footer ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateFooter?
Footer section of a message template
41 |
# File 'lib/sentdm/models/template_definition.rb', line 41 optional :footer, -> { Sentdm::SentDmServicesCommonContractsPocOsTemplateFooter }, nil?: true |
#header ⇒ Sentdm::Models::SentDmServicesCommonContractsPocOsTemplateHeader?
Header section of a message template
47 |
# File 'lib/sentdm/models/template_definition.rb', line 47 optional :header, -> { Sentdm::SentDmServicesCommonContractsPocOsTemplateHeader }, nil?: true |