Class: Sentdm::Models::TemplateDeleteParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/template_delete_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, delete_from_meta: nil, sandbox: nil, x_profile_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::TemplateDeleteParams for more details.

Parameters:

  • id (String)
  • delete_from_meta (Boolean, nil) (defaults to: nil)

    Whether to also delete the template from WhatsApp/Meta (optional, defaults to fa

  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects

  • x_profile_id (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/template_delete_params.rb', line 34

Instance Attribute Details

#delete_from_metaBoolean?

Whether to also delete the template from WhatsApp/Meta (optional, defaults to false)

Returns:

  • (Boolean, nil)


20
# File 'lib/sentdm/models/template_delete_params.rb', line 20

optional :delete_from_meta, Sentdm::Internal::Type::Boolean, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/sentdm/models/template_delete_params.rb', line 13

required :id, String

#sandboxBoolean?

Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


27
# File 'lib/sentdm/models/template_delete_params.rb', line 27

optional :sandbox, Sentdm::Internal::Type::Boolean

#x_profile_idString?

Returns:

  • (String, nil)


32
# File 'lib/sentdm/models/template_delete_params.rb', line 32

optional :x_profile_id, String