Class: Sentdm::Models::TemplateUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::TemplateUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sentdm/models/template_update_params.rb
Overview
Instance Attribute Summary collapse
-
#category ⇒ String?
Template category: MARKETING, UTILITY, AUTHENTICATION.
-
#definition ⇒ Sentdm::Models::TemplateDefinition?
Complete definition of a message template including header, body, footer, and buttons.
- #id ⇒ String
- #idempotency_key ⇒ String?
-
#language ⇒ String?
Template language code (e.g., en_US).
-
#name ⇒ String?
Template display name.
-
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution.
-
#submit_for_review ⇒ Boolean?
Whether to submit the template for review after updating (default: false).
- #x_profile_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, category: nil, definition: nil, language: nil, name: nil, sandbox: nil, submit_for_review: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TemplateUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, category: nil, definition: nil, language: nil, name: nil, sandbox: nil, submit_for_review: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::TemplateUpdateParams for more details.
|
|
# File 'lib/sentdm/models/template_update_params.rb', line 63
|
Instance Attribute Details
#category ⇒ String?
Template category: MARKETING, UTILITY, AUTHENTICATION
19 |
# File 'lib/sentdm/models/template_update_params.rb', line 19 optional :category, String, nil?: true |
#definition ⇒ Sentdm::Models::TemplateDefinition?
Complete definition of a message template including header, body, footer, and buttons
26 |
# File 'lib/sentdm/models/template_update_params.rb', line 26 optional :definition, -> { Sentdm::TemplateDefinition }, nil?: true |
#id ⇒ String
13 |
# File 'lib/sentdm/models/template_update_params.rb', line 13 required :id, String |
#idempotency_key ⇒ String?
56 |
# File 'lib/sentdm/models/template_update_params.rb', line 56 optional :idempotency_key, String |
#language ⇒ String?
Template language code (e.g., en_US)
32 |
# File 'lib/sentdm/models/template_update_params.rb', line 32 optional :language, String, nil?: true |
#name ⇒ String?
Template display name
38 |
# File 'lib/sentdm/models/template_update_params.rb', line 38 optional :name, String, nil?: true |
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
45 |
# File 'lib/sentdm/models/template_update_params.rb', line 45 optional :sandbox, Sentdm::Internal::Type::Boolean |
#submit_for_review ⇒ Boolean?
Whether to submit the template for review after updating (default: false)
51 |
# File 'lib/sentdm/models/template_update_params.rb', line 51 optional :submit_for_review, Sentdm::Internal::Type::Boolean |
#x_profile_id ⇒ String?
61 |
# File 'lib/sentdm/models/template_update_params.rb', line 61 optional :x_profile_id, String |