Class: Sentdm::Models::TemplateUpdateParams::Definition::Body
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::TemplateUpdateParams::Definition::Body
- Defined in:
- lib/sentdm/models/template_update_params.rb
Overview
Defined Under Namespace
Classes: MultiChannel, Rcs, SMS, Whatsapp
Instance Attribute Summary collapse
-
#multi_channel ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::MultiChannel?
Content that will be used for all channels (SMS and WhatsApp) unless channel-specific content is provided.
-
#rcs ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::Rcs?
RCS-specific content that overrides multi-channel content for RCS messages.
-
#sms ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::SMS?
SMS-specific content that overrides multi-channel content for SMS messages.
-
#whatsapp ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::Whatsapp?
WhatsApp-specific content that overrides multi-channel content for WhatsApp messages.
Instance Method Summary collapse
- #initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(media_type:, sample:, url:, variable_type:, alt: nil, regex: nil, short_url: nil) ⇒ Object
|
|
# File 'lib/sentdm/models/template_update_params.rb', line 176
|
Instance Attribute Details
#multi_channel ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::MultiChannel?
Content that will be used for all channels (SMS and WhatsApp) unless channel-specific content is provided
152 153 154 155 |
# File 'lib/sentdm/models/template_update_params.rb', line 152 optional :multi_channel, -> { Sentdm::TemplateUpdateParams::Definition::Body::MultiChannel }, api_name: :multiChannel, nil?: true |
#rcs ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::Rcs?
RCS-specific content that overrides multi-channel content for RCS messages
161 |
# File 'lib/sentdm/models/template_update_params.rb', line 161 optional :rcs, -> { Sentdm::TemplateUpdateParams::Definition::Body::Rcs }, nil?: true |
#sms ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::SMS?
SMS-specific content that overrides multi-channel content for SMS messages
167 |
# File 'lib/sentdm/models/template_update_params.rb', line 167 optional :sms, -> { Sentdm::TemplateUpdateParams::Definition::Body::SMS }, nil?: true |
#whatsapp ⇒ Sentdm::Models::TemplateUpdateParams::Definition::Body::Whatsapp?
WhatsApp-specific content that overrides multi-channel content for WhatsApp messages
174 |
# File 'lib/sentdm/models/template_update_params.rb', line 174 optional :whatsapp, -> { Sentdm::TemplateUpdateParams::Definition::Body::Whatsapp }, nil?: true |