Class: Sentdm::Models::UserListResponse::Data::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::UserListResponse::Data::User
- Defined in:
- lib/sentdm/models/user_list_response.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
When the user was added to the organization.
-
#email ⇒ String?
User email address.
-
#id ⇒ String?
User unique identifier.
-
#invited_at ⇒ Time?
When the user was invited.
-
#last_login_at ⇒ Time?
When the user last logged in.
-
#name ⇒ String?
User full name.
-
#role ⇒ String?
User role in the organization: admin, billing, developer.
-
#status ⇒ String?
User status: active, invited, suspended, rejected.
-
#updated_at ⇒ Time?
When the user record was last updated.
Instance Method Summary collapse
-
#initialize(users: nil) ⇒ Object
constructor
List of users response.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(users: nil) ⇒ Object
List of users response
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/sentdm/models/user_list_response.rb', line 55 class User < Sentdm::Internal::Type::BaseModel # @!attribute id # User unique identifier # # @return [String, nil] optional :id, String # @!attribute created_at # When the user was added to the organization # # @return [Time, nil] optional :created_at, Time # @!attribute email # User email address # # @return [String, nil] optional :email, String # @!attribute invited_at # When the user was invited # # @return [Time, nil] optional :invited_at, Time, nil?: true # @!attribute last_login_at # When the user last logged in # # @return [Time, nil] optional :last_login_at, Time, nil?: true # @!attribute name # User full name # # @return [String, nil] optional :name, String # @!attribute role # User role in the organization: admin, billing, developer # # @return [String, nil] optional :role, String # @!attribute status # User status: active, invited, suspended, rejected # # @return [String, nil] optional :status, String # @!attribute updated_at # When the user record was last updated # # @return [Time, nil] optional :updated_at, Time, nil?: true # @!method initialize(id: nil, created_at: nil, email: nil, invited_at: nil, last_login_at: nil, name: nil, role: nil, status: nil, updated_at: nil) # User response for v3 API # # @param id [String] User unique identifier # # @param created_at [Time] When the user was added to the organization # # @param email [String] User email address # # @param invited_at [Time, nil] When the user was invited # # @param last_login_at [Time, nil] When the user last logged in # # @param name [String] User full name # # @param role [String] User role in the organization: admin, billing, developer # # @param status [String] User status: active, invited, suspended, rejected # # @param updated_at [Time, nil] When the user record was last updated end |
Instance Attribute Details
#created_at ⇒ Time?
When the user was added to the organization
66 |
# File 'lib/sentdm/models/user_list_response.rb', line 66 optional :created_at, Time |
#email ⇒ String?
User email address
72 |
# File 'lib/sentdm/models/user_list_response.rb', line 72 optional :email, String |
#id ⇒ String?
User unique identifier
60 |
# File 'lib/sentdm/models/user_list_response.rb', line 60 optional :id, String |
#invited_at ⇒ Time?
When the user was invited
78 |
# File 'lib/sentdm/models/user_list_response.rb', line 78 optional :invited_at, Time, nil?: true |
#last_login_at ⇒ Time?
When the user last logged in
84 |
# File 'lib/sentdm/models/user_list_response.rb', line 84 optional :last_login_at, Time, nil?: true |
#name ⇒ String?
User full name
90 |
# File 'lib/sentdm/models/user_list_response.rb', line 90 optional :name, String |
#role ⇒ String?
User role in the organization: admin, billing, developer
96 |
# File 'lib/sentdm/models/user_list_response.rb', line 96 optional :role, String |
#status ⇒ String?
User status: active, invited, suspended, rejected
102 |
# File 'lib/sentdm/models/user_list_response.rb', line 102 optional :status, String |
#updated_at ⇒ Time?
When the user record was last updated
108 |
# File 'lib/sentdm/models/user_list_response.rb', line 108 optional :updated_at, Time, nil?: true |