Class: Sentdm::Models::WebhookCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/webhook_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(display_name: nil, endpoint_url: nil, event_filters: nil, event_types: nil, retry_count: nil, sandbox: nil, timeout_seconds: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::WebhookCreateParams for more details.

Parameters:

  • display_name (String) (defaults to: nil)
  • endpoint_url (String) (defaults to: nil)
  • event_filters (Hash{Symbol=>Array<String>}, nil) (defaults to: nil)
  • event_types (Array<String>) (defaults to: nil)
  • retry_count (Integer) (defaults to: nil)
  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects

  • timeout_seconds (Integer) (defaults to: nil)
  • idempotency_key (String) (defaults to: nil)
  • x_profile_id (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/webhook_create_params.rb', line 59

Instance Attribute Details

#display_nameString?

Returns:

  • (String, nil)


13
# File 'lib/sentdm/models/webhook_create_params.rb', line 13

optional :display_name, String

#endpoint_urlString?

Returns:

  • (String, nil)


18
# File 'lib/sentdm/models/webhook_create_params.rb', line 18

optional :endpoint_url, String

#event_filtersHash{Symbol=>Array<String>}?

Returns:

  • (Hash{Symbol=>Array<String>}, nil)


23
24
25
# File 'lib/sentdm/models/webhook_create_params.rb', line 23

optional :event_filters,
Sentdm::Internal::Type::HashOf[Sentdm::Internal::Type::ArrayOf[String]],
nil?: true

#event_typesArray<String>?

Returns:

  • (Array<String>, nil)


30
# File 'lib/sentdm/models/webhook_create_params.rb', line 30

optional :event_types, Sentdm::Internal::Type::ArrayOf[String]

#idempotency_keyString?

Returns:

  • (String, nil)


52
# File 'lib/sentdm/models/webhook_create_params.rb', line 52

optional :idempotency_key, String

#retry_countInteger?

Returns:

  • (Integer, nil)


35
# File 'lib/sentdm/models/webhook_create_params.rb', line 35

optional :retry_count, Integer

#sandboxBoolean?

Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


42
# File 'lib/sentdm/models/webhook_create_params.rb', line 42

optional :sandbox, Sentdm::Internal::Type::Boolean

#timeout_secondsInteger?

Returns:

  • (Integer, nil)


47
# File 'lib/sentdm/models/webhook_create_params.rb', line 47

optional :timeout_seconds, Integer

#x_profile_idString?

Returns:

  • (String, nil)


57
# File 'lib/sentdm/models/webhook_create_params.rb', line 57

optional :x_profile_id, String