Class: Sentdm::Models::WebhookToggleStatusParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::WebhookToggleStatusParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sentdm/models/webhook_toggle_status_params.rb
Overview
Instance Attribute Summary collapse
- #id ⇒ String
- #idempotency_key ⇒ String?
- #is_active ⇒ Boolean?
-
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution.
- #x_profile_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, is_active: nil, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebhookToggleStatusParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, is_active: nil, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::WebhookToggleStatusParams for more details.
|
|
# File 'lib/sentdm/models/webhook_toggle_status_params.rb', line 37
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/sentdm/models/webhook_toggle_status_params.rb', line 13 required :id, String |
#idempotency_key ⇒ String?
30 |
# File 'lib/sentdm/models/webhook_toggle_status_params.rb', line 30 optional :idempotency_key, String |
#is_active ⇒ Boolean?
18 |
# File 'lib/sentdm/models/webhook_toggle_status_params.rb', line 18 optional :is_active, Sentdm::Internal::Type::Boolean |
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
25 |
# File 'lib/sentdm/models/webhook_toggle_status_params.rb', line 25 optional :sandbox, Sentdm::Internal::Type::Boolean |
#x_profile_id ⇒ String?
35 |
# File 'lib/sentdm/models/webhook_toggle_status_params.rb', line 35 optional :x_profile_id, String |