Class: Sentdm::Models::BillingContactInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::BillingContactInfo
- Defined in:
- lib/sentdm/models/billing_contact_info.rb
Instance Attribute Summary collapse
-
#address ⇒ String?
Billing address (optional).
-
#email ⇒ String
Email address where invoices will be sent (required).
-
#name ⇒ String
Full name of the billing contact or company (required).
-
#phone ⇒ String?
Phone number for the billing contact (optional).
Instance Method Summary collapse
-
#initialize(email:, name:, address: nil, phone: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BillingContactInfo for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email:, name:, address: nil, phone: nil) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::BillingContactInfo for more details.
Billing contact information for a profile. Required when billing_model is “profile” or “profile_and_organization”.
|
|
# File 'lib/sentdm/models/billing_contact_info.rb', line 31
|
Instance Attribute Details
#address ⇒ String?
Billing address (optional). Free-form text including street, city, state, postal code, and country.
23 |
# File 'lib/sentdm/models/billing_contact_info.rb', line 23 optional :address, String, nil?: true |
#email ⇒ String
Email address where invoices will be sent (required)
10 |
# File 'lib/sentdm/models/billing_contact_info.rb', line 10 required :email, String |
#name ⇒ String
Full name of the billing contact or company (required)
16 |
# File 'lib/sentdm/models/billing_contact_info.rb', line 16 required :name, String |
#phone ⇒ String?
Phone number for the billing contact (optional)
29 |
# File 'lib/sentdm/models/billing_contact_info.rb', line 29 optional :phone, String, nil?: true |