Class: Sentdm::Models::ContactCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ContactCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sentdm/models/contact_create_params.rb
Overview
Instance Attribute Summary collapse
- #idempotency_key ⇒ String?
-
#phone_number ⇒ String?
Phone number of the contact to create.
-
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution.
- #x_profile_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(phone_number: nil, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContactCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(phone_number: nil, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::ContactCreateParams for more details.
|
|
# File 'lib/sentdm/models/contact_create_params.rb', line 33
|
Instance Attribute Details
#idempotency_key ⇒ String?
26 |
# File 'lib/sentdm/models/contact_create_params.rb', line 26 optional :idempotency_key, String |
#phone_number ⇒ String?
Phone number of the contact to create
14 |
# File 'lib/sentdm/models/contact_create_params.rb', line 14 optional :phone_number, String |
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
21 |
# File 'lib/sentdm/models/contact_create_params.rb', line 21 optional :sandbox, Sentdm::Internal::Type::Boolean |
#x_profile_id ⇒ String?
31 |
# File 'lib/sentdm/models/contact_create_params.rb', line 31 optional :x_profile_id, String |