Class: Sentdm::Models::ContactResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ContactResponse
- Defined in:
- lib/sentdm/models/contact_response.rb
Instance Attribute Summary collapse
-
#available_channels ⇒ String?
Comma-separated list of available messaging channels (e.g., “sms,whatsapp”).
-
#channel_consent ⇒ Hash{Symbol=>String}?
Consent status by channel.
-
#country_code ⇒ String?
Country calling code (e.g., 1 for US/Canada).
-
#created_at ⇒ Time?
When the contact was created.
-
#default_channel ⇒ String?
Default messaging channel to use (e.g., “sms” or “whatsapp”).
-
#format_e164 ⇒ String?
Phone number in E.164 format (e.g., +1234567890).
-
#format_international ⇒ String?
Phone number in international format (e.g., +1 234-567-890).
-
#format_national ⇒ String?
Phone number in national format (e.g., (234) 567-890).
-
#format_rfc ⇒ String?
Phone number in RFC 3966 format (e.g., tel:+1-234-567-890).
-
#id ⇒ String?
Unique identifier for the contact.
-
#is_inherited ⇒ Boolean?
Whether this is an inherited contact (read-only).
-
#opt_out ⇒ Boolean?
Whether the contact has opted out of messaging.
-
#phone_number ⇒ String?
Phone number in original format.
-
#region_code ⇒ String?
ISO 3166-1 alpha-2 country code (e.g., US, CA, GB).
-
#updated_at ⇒ Time?
When the contact was last updated.
Instance Method Summary collapse
-
#initialize(id: nil, available_channels: nil, channel_consent: nil, country_code: nil, created_at: nil, default_channel: nil, format_e164: nil, format_international: nil, format_national: nil, format_rfc: nil, is_inherited: nil, opt_out: nil, phone_number: nil, region_code: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContactResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, available_channels: nil, channel_consent: nil, country_code: nil, created_at: nil, default_channel: nil, format_e164: nil, format_international: nil, format_national: nil, format_rfc: nil, is_inherited: nil, opt_out: nil, phone_number: nil, region_code: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::ContactResponse for more details.
Contact response for v3 API Uses snake_case for JSON property names
|
|
# File 'lib/sentdm/models/contact_response.rb', line 99
|
Instance Attribute Details
#available_channels ⇒ String?
Comma-separated list of available messaging channels (e.g., “sms,whatsapp”)
16 |
# File 'lib/sentdm/models/contact_response.rb', line 16 optional :available_channels, String |
#channel_consent ⇒ Hash{Symbol=>String}?
Consent status by channel. Keys: “sms”, “whatsapp”. Values: “opted_in”, “opted_out”. All channels will have the same status because consent is global across channels. A STOP on any channel opts out of all channels; a START opts in to all.
25 |
# File 'lib/sentdm/models/contact_response.rb', line 25 optional :channel_consent, Sentdm::Internal::Type::HashOf[String], nil?: true |
#country_code ⇒ String?
Country calling code (e.g., 1 for US/Canada)
31 |
# File 'lib/sentdm/models/contact_response.rb', line 31 optional :country_code, String |
#created_at ⇒ Time?
When the contact was created
37 |
# File 'lib/sentdm/models/contact_response.rb', line 37 optional :created_at, Time |
#default_channel ⇒ String?
Default messaging channel to use (e.g., “sms” or “whatsapp”)
43 |
# File 'lib/sentdm/models/contact_response.rb', line 43 optional :default_channel, String |
#format_e164 ⇒ String?
Phone number in E.164 format (e.g., +1234567890)
49 |
# File 'lib/sentdm/models/contact_response.rb', line 49 optional :format_e164, String |
#format_international ⇒ String?
Phone number in international format (e.g., +1 234-567-890)
55 |
# File 'lib/sentdm/models/contact_response.rb', line 55 optional :format_international, String |
#format_national ⇒ String?
Phone number in national format (e.g., (234) 567-890)
61 |
# File 'lib/sentdm/models/contact_response.rb', line 61 optional :format_national, String |
#format_rfc ⇒ String?
Phone number in RFC 3966 format (e.g., tel:+1-234-567-890)
67 |
# File 'lib/sentdm/models/contact_response.rb', line 67 optional :format_rfc, String |
#id ⇒ String?
Unique identifier for the contact
10 |
# File 'lib/sentdm/models/contact_response.rb', line 10 optional :id, String |
#is_inherited ⇒ Boolean?
Whether this is an inherited contact (read-only)
73 |
# File 'lib/sentdm/models/contact_response.rb', line 73 optional :is_inherited, Sentdm::Internal::Type::Boolean |
#opt_out ⇒ Boolean?
Whether the contact has opted out of messaging
79 |
# File 'lib/sentdm/models/contact_response.rb', line 79 optional :opt_out, Sentdm::Internal::Type::Boolean |
#phone_number ⇒ String?
Phone number in original format
85 |
# File 'lib/sentdm/models/contact_response.rb', line 85 optional :phone_number, String |
#region_code ⇒ String?
ISO 3166-1 alpha-2 country code (e.g., US, CA, GB)
91 |
# File 'lib/sentdm/models/contact_response.rb', line 91 optional :region_code, String |
#updated_at ⇒ Time?
When the contact was last updated
97 |
# File 'lib/sentdm/models/contact_response.rb', line 97 optional :updated_at, Time, nil?: true |