Class: Sentdm::Models::ContactUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/contact_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, default_channel: nil, opt_out: nil, test_mode: nil, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ContactUpdateParams for more details.

Parameters:

  • id (String)
  • default_channel (String, nil) (defaults to: nil)

    Default messaging channel: “sms” or “whatsapp”

  • opt_out (Boolean, nil) (defaults to: nil)

    Whether the contact has opted out of messaging

  • test_mode (Boolean) (defaults to: nil)

    Test mode flag - when true, the operation is simulated without side effects

  • idempotency_key (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/contact_update_params.rb', line 39

Instance Attribute Details

#default_channelString?

Default messaging channel: “sms” or “whatsapp”

Returns:

  • (String, nil)


19
# File 'lib/sentdm/models/contact_update_params.rb', line 19

optional :default_channel, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/sentdm/models/contact_update_params.rb', line 13

required :id, String

#idempotency_keyString?

Returns:

  • (String, nil)


37
# File 'lib/sentdm/models/contact_update_params.rb', line 37

optional :idempotency_key, String

#opt_outBoolean?

Whether the contact has opted out of messaging

Returns:

  • (Boolean, nil)


25
# File 'lib/sentdm/models/contact_update_params.rb', line 25

optional :opt_out, Sentdm::Internal::Type::Boolean, nil?: true

#test_modeBoolean?

Test mode flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


32
# File 'lib/sentdm/models/contact_update_params.rb', line 32

optional :test_mode, Sentdm::Internal::Type::Boolean