Class: Sentdm::Models::MeRetrieveResponse::Data::Settings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::MeRetrieveResponse::Data::Settings
- Defined in:
- lib/sentdm/models/me_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#allow_contact_sharing ⇒ Boolean?
Whether contacts are shared across profiles in the organization.
-
#allow_template_sharing ⇒ Boolean?
Whether templates are shared across profiles in the organization.
-
#billing_model ⇒ String?
Billing model: profile, organization, or profile_and_organization.
-
#inherit_contacts ⇒ Boolean?
Whether this profile inherits contacts from the organization.
-
#inherit_tcr_brand ⇒ Boolean?
Whether this profile inherits TCR brand from the organization.
-
#inherit_tcr_campaign ⇒ Boolean?
Whether this profile inherits TCR campaign from the organization.
-
#inherit_templates ⇒ Boolean?
Whether this profile inherits templates from the organization.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Sentdm::Internal::Type::BaseModel
Instance Attribute Details
#allow_contact_sharing ⇒ Boolean?
Whether contacts are shared across profiles in the organization
425 |
# File 'lib/sentdm/models/me_retrieve_response.rb', line 425 optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean, nil?: true |
#allow_template_sharing ⇒ Boolean?
Whether templates are shared across profiles in the organization
431 |
# File 'lib/sentdm/models/me_retrieve_response.rb', line 431 optional :allow_template_sharing, Sentdm::Internal::Type::Boolean, nil?: true |
#billing_model ⇒ String?
Billing model: profile, organization, or profile_and_organization
437 |
# File 'lib/sentdm/models/me_retrieve_response.rb', line 437 optional :billing_model, String, nil?: true |
#inherit_contacts ⇒ Boolean?
Whether this profile inherits contacts from the organization
443 |
# File 'lib/sentdm/models/me_retrieve_response.rb', line 443 optional :inherit_contacts, Sentdm::Internal::Type::Boolean, nil?: true |
#inherit_tcr_brand ⇒ Boolean?
Whether this profile inherits TCR brand from the organization
449 |
# File 'lib/sentdm/models/me_retrieve_response.rb', line 449 optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean, nil?: true |