Class: Sentdm::Models::ProfileCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/profile_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allow_contact_sharing: nil, allow_template_sharing: nil, billing_model: nil, description: nil, icon: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, name: nil, short_name: nil, test_mode: nil, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ProfileCreateParams for more details.

Parameters:

  • allow_contact_sharing (Boolean) (defaults to: nil)

    Whether contacts are shared across profiles (default: false)

  • allow_template_sharing (Boolean) (defaults to: nil)

    Whether templates are shared across profiles (default: false)

  • billing_model (String, nil) (defaults to: nil)

    Billing model: profile, organization, or profile_and_organization (default: prof

  • description (String, nil) (defaults to: nil)

    Profile description (optional)

  • icon (String, nil) (defaults to: nil)

    Profile icon URL (optional)

  • inherit_contacts (Boolean, nil) (defaults to: nil)

    Whether this profile inherits contacts from organization (default: true)

  • inherit_tcr_brand (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR brand from organization (default: true)

  • inherit_tcr_campaign (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR campaign from organization (default: true)

  • inherit_templates (Boolean, nil) (defaults to: nil)

    Whether this profile inherits templates from organization (default: true)

  • name (String) (defaults to: nil)

    Profile name (required)

  • short_name (String, nil) (defaults to: nil)

    Profile short name/abbreviation (optional)

  • test_mode (Boolean) (defaults to: nil)

    Test mode flag - when true, the operation is simulated without side effects

  • idempotency_key (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/profile_create_params.rb', line 89

Instance Attribute Details

#allow_contact_sharingBoolean?

Whether contacts are shared across profiles (default: false)

Returns:

  • (Boolean, nil)


14
# File 'lib/sentdm/models/profile_create_params.rb', line 14

optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean

#allow_template_sharingBoolean?

Whether templates are shared across profiles (default: false)

Returns:

  • (Boolean, nil)


20
# File 'lib/sentdm/models/profile_create_params.rb', line 20

optional :allow_template_sharing, Sentdm::Internal::Type::Boolean

#billing_modelString?

Billing model: profile, organization, or profile_and_organization (default: profile)

Returns:

  • (String, nil)


27
# File 'lib/sentdm/models/profile_create_params.rb', line 27

optional :billing_model, String, nil?: true

#descriptionString?

Profile description (optional)

Returns:

  • (String, nil)


33
# File 'lib/sentdm/models/profile_create_params.rb', line 33

optional :description, String, nil?: true

#iconString?

Profile icon URL (optional)

Returns:

  • (String, nil)


39
# File 'lib/sentdm/models/profile_create_params.rb', line 39

optional :icon, String, nil?: true

#idempotency_keyString?

Returns:

  • (String, nil)


87
# File 'lib/sentdm/models/profile_create_params.rb', line 87

optional :idempotency_key, String

#inherit_contactsBoolean?

Whether this profile inherits contacts from organization (default: true)

Returns:

  • (Boolean, nil)


45
# File 'lib/sentdm/models/profile_create_params.rb', line 45

optional :inherit_contacts, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_brandBoolean?

Whether this profile inherits TCR brand from organization (default: true)

Returns:

  • (Boolean, nil)


51
# File 'lib/sentdm/models/profile_create_params.rb', line 51

optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_campaignBoolean?

Whether this profile inherits TCR campaign from organization (default: true)

Returns:

  • (Boolean, nil)


57
# File 'lib/sentdm/models/profile_create_params.rb', line 57

optional :inherit_tcr_campaign, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_templatesBoolean?

Whether this profile inherits templates from organization (default: true)

Returns:

  • (Boolean, nil)


63
# File 'lib/sentdm/models/profile_create_params.rb', line 63

optional :inherit_templates, Sentdm::Internal::Type::Boolean, nil?: true

#nameString?

Profile name (required)

Returns:

  • (String, nil)


69
# File 'lib/sentdm/models/profile_create_params.rb', line 69

optional :name, String

#short_nameString?

Profile short name/abbreviation (optional)

Returns:

  • (String, nil)


75
# File 'lib/sentdm/models/profile_create_params.rb', line 75

optional :short_name, String, nil?: true

#test_modeBoolean?

Test mode flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


82
# File 'lib/sentdm/models/profile_create_params.rb', line 82

optional :test_mode, Sentdm::Internal::Type::Boolean