Class: Sentdm::Models::ProfileCreateParams::WhatsappBusinessAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileCreateParams::WhatsappBusinessAccount
- Defined in:
- lib/sentdm/models/profile_create_params.rb
Instance Attribute Summary collapse
-
#access_token ⇒ String
System User access token with whatsapp_business_messaging and whatsapp_business_management permissions.
-
#phone_number_id ⇒ String?
Phone Number ID of an existing number already registered under this WABA in Meta Business Manager.
-
#waba_id ⇒ String
WhatsApp Business Account ID from Meta Business Manager.
Instance Method Summary collapse
-
#initialize(access_token:, waba_id:, phone_number_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhatsappBusinessAccount for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_token:, waba_id:, phone_number_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::ProfileCreateParams::WhatsappBusinessAccount for more details.
Direct WhatsApp Business Account credentials for a profile. Use this when the profile should have its own WhatsApp Business Account instead of inheriting from the organization. Credentials must be obtained from Meta Business Manager by creating a System User with whatsapp_business_messaging and whatsapp_business_management scopes.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/sentdm/models/profile_create_params.rb', line 177 class WhatsappBusinessAccount < Sentdm::Internal::Type::BaseModel # @!attribute access_token # System User access token with whatsapp_business_messaging and # whatsapp_business_management permissions. This value is stored securely and # never returned in API responses. # # @return [String] required :access_token, String # @!attribute waba_id # WhatsApp Business Account ID from Meta Business Manager # # @return [String] required :waba_id, String # @!attribute phone_number_id # Phone Number ID of an existing number already registered under this WABA in Meta # Business Manager. Optional — when omitted, a number will be provisioned from our # pool and registered in the WABA during the onboarding flow. When provided, the # number must already exist in the WABA. # # @return [String, nil] optional :phone_number_id, String, nil?: true # @!method initialize(access_token:, waba_id:, phone_number_id: nil) # Some parameter documentations has been truncated, see # {Sentdm::Models::ProfileCreateParams::WhatsappBusinessAccount} for more details. # # Direct WhatsApp Business Account credentials for a profile. Use this when the # profile should have its own WhatsApp Business Account instead of inheriting from # the organization. Credentials must be obtained from Meta Business Manager by # creating a System User with whatsapp_business_messaging and # whatsapp_business_management scopes. # # @param access_token [String] System User access token with whatsapp_business_messaging and # # @param waba_id [String] WhatsApp Business Account ID from Meta Business Manager # # @param phone_number_id [String, nil] Phone Number ID of an existing number already registered under this WABA in Meta end |
Instance Attribute Details
#access_token ⇒ String
System User access token with whatsapp_business_messaging and whatsapp_business_management permissions. This value is stored securely and never returned in API responses.
184 |
# File 'lib/sentdm/models/profile_create_params.rb', line 184 required :access_token, String |
#phone_number_id ⇒ String?
Phone Number ID of an existing number already registered under this WABA in Meta Business Manager. Optional — when omitted, a number will be provisioned from our pool and registered in the WABA during the onboarding flow. When provided, the number must already exist in the WABA.
199 |
# File 'lib/sentdm/models/profile_create_params.rb', line 199 optional :phone_number_id, String, nil?: true |
#waba_id ⇒ String
WhatsApp Business Account ID from Meta Business Manager
190 |
# File 'lib/sentdm/models/profile_create_params.rb', line 190 required :waba_id, String |