Class: Sentdm::Models::ProfileDetail::Brand
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileDetail::Brand
- Defined in:
- lib/sentdm/models/profile_detail.rb
Overview
Defined Under Namespace
Modules: IdentityStatus, Status Classes: Business, Compliance, Contact
Instance Attribute Summary collapse
-
#business ⇒ Sentdm::Models::ProfileDetail::Brand::Business?
Business details and address information.
-
#compliance ⇒ Sentdm::Models::ProfileDetail::Brand::Compliance?
Compliance and TCR-related information.
-
#contact ⇒ Sentdm::Models::ProfileDetail::Brand::Contact?
Contact information for the brand.
-
#created_at ⇒ Time?
When the brand was created.
-
#csp_id ⇒ String?
CSP (Campaign Service Provider) ID.
-
#id ⇒ String?
Unique identifier for the brand.
- #identity_status ⇒ Symbol, ...
-
#is_inherited ⇒ Boolean?
Whether this brand is inherited from the parent organization.
- #status ⇒ Symbol, ...
-
#submitted_at ⇒ Time?
When the brand was submitted to TCR.
-
#submitted_to_tcr ⇒ Boolean?
Whether this brand has been submitted to TCR.
-
#tcr_brand_id ⇒ String?
TCR brand ID (populated after TCR submission).
-
#universal_ein ⇒ String?
Universal EIN from TCR.
-
#updated_at ⇒ Time?
When the brand was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(business_name: nil, email: nil, name: nil, phone: nil, phone_country_code: nil, role: nil) ⇒ Object
constructor
Contact information for the brand.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business_name: nil, email: nil, name: nil, phone: nil, phone_country_code: nil, role: nil) ⇒ Object
Contact information for the brand
|
|
# File 'lib/sentdm/models/profile_detail.rb', line 330
|
Instance Attribute Details
#business ⇒ Sentdm::Models::ProfileDetail::Brand::Business?
Business details and address information
258 |
# File 'lib/sentdm/models/profile_detail.rb', line 258 optional :business, -> { Sentdm::ProfileDetail::Brand::Business }, nil?: true |
#compliance ⇒ Sentdm::Models::ProfileDetail::Brand::Compliance?
Compliance and TCR-related information
264 |
# File 'lib/sentdm/models/profile_detail.rb', line 264 optional :compliance, -> { Sentdm::ProfileDetail::Brand::Compliance }, nil?: true |
#contact ⇒ Sentdm::Models::ProfileDetail::Brand::Contact?
Contact information for the brand
270 |
# File 'lib/sentdm/models/profile_detail.rb', line 270 optional :contact, -> { Sentdm::ProfileDetail::Brand::Contact }, nil?: true |
#created_at ⇒ Time?
When the brand was created
276 |
# File 'lib/sentdm/models/profile_detail.rb', line 276 optional :created_at, Time |
#csp_id ⇒ String?
CSP (Campaign Service Provider) ID
282 |
# File 'lib/sentdm/models/profile_detail.rb', line 282 optional :csp_id, String, nil?: true |
#id ⇒ String?
Unique identifier for the brand
252 |
# File 'lib/sentdm/models/profile_detail.rb', line 252 optional :id, String |
#identity_status ⇒ Symbol, ...
287 |
# File 'lib/sentdm/models/profile_detail.rb', line 287 optional :identity_status, enum: -> { Sentdm::ProfileDetail::Brand::IdentityStatus }, nil?: true |
#is_inherited ⇒ Boolean?
Whether this brand is inherited from the parent organization
293 |
# File 'lib/sentdm/models/profile_detail.rb', line 293 optional :is_inherited, Sentdm::Internal::Type::Boolean |
#status ⇒ Symbol, ...
298 |
# File 'lib/sentdm/models/profile_detail.rb', line 298 optional :status, enum: -> { Sentdm::ProfileDetail::Brand::Status }, nil?: true |
#submitted_at ⇒ Time?
When the brand was submitted to TCR
304 |
# File 'lib/sentdm/models/profile_detail.rb', line 304 optional :submitted_at, Time, nil?: true |
#submitted_to_tcr ⇒ Boolean?
Whether this brand has been submitted to TCR
310 |
# File 'lib/sentdm/models/profile_detail.rb', line 310 optional :submitted_to_tcr, Sentdm::Internal::Type::Boolean |
#tcr_brand_id ⇒ String?
TCR brand ID (populated after TCR submission)
316 |
# File 'lib/sentdm/models/profile_detail.rb', line 316 optional :tcr_brand_id, String, nil?: true |
#universal_ein ⇒ String?
Universal EIN from TCR
322 |
# File 'lib/sentdm/models/profile_detail.rb', line 322 optional :universal_ein, String, nil?: true |
#updated_at ⇒ Time?
When the brand was last updated
328 |
# File 'lib/sentdm/models/profile_detail.rb', line 328 optional :updated_at, Time, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/sentdm/models/profile_detail.rb', line 587
|