Class: Sentdm::Models::ProfileDetail::Settings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileDetail::Settings
- Defined in:
- lib/sentdm/models/profile_detail.rb
Overview
Instance Attribute Summary collapse
-
#allow_contact_sharing ⇒ Boolean?
Whether contacts are shared across profiles in the organization.
-
#allow_number_change_during_onboarding ⇒ Boolean?
Whether number changes are allowed during onboarding.
-
#allow_template_sharing ⇒ Boolean?
Whether templates are shared across profiles in the organization.
-
#billing_model ⇒ String?
Billing model: profile, organization, or profile_and_organization.
-
#inherit_contacts ⇒ Boolean?
Whether this profile inherits contacts from the organization.
-
#inherit_tcr_brand ⇒ Boolean?
Whether this profile inherits TCR brand from the organization.
-
#inherit_tcr_campaign ⇒ Boolean?
Whether this profile inherits TCR campaign from the organization.
-
#inherit_templates ⇒ Boolean?
Whether this profile inherits templates from the organization.
-
#sending_phone_number ⇒ String?
Direct SMS phone number.
-
#sending_phone_number_profile_id ⇒ String?
Reference to another profile for SMS/Telnyx configuration.
-
#sending_whatsapp_number_profile_id ⇒ String?
Reference to another profile for WhatsApp configuration.
-
#whatsapp_phone_number ⇒ String?
Direct WhatsApp phone number.
Instance Method Summary collapse
-
#initialize(allow_contact_sharing: nil, allow_number_change_during_onboarding: nil, allow_template_sharing: nil, billing_model: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, sending_phone_number: nil, sending_phone_number_profile_id: nil, sending_whatsapp_number_profile_id: nil, whatsapp_phone_number: nil) ⇒ Object
constructor
Profile configuration settings.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allow_contact_sharing: nil, allow_number_change_during_onboarding: nil, allow_template_sharing: nil, billing_model: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, sending_phone_number: nil, sending_phone_number_profile_id: nil, sending_whatsapp_number_profile_id: nil, whatsapp_phone_number: nil) ⇒ Object
Profile configuration settings
|
|
# File 'lib/sentdm/models/profile_detail.rb', line 171
|
Instance Attribute Details
#allow_contact_sharing ⇒ Boolean?
Whether contacts are shared across profiles in the organization
103 |
# File 'lib/sentdm/models/profile_detail.rb', line 103 optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean |
#allow_number_change_during_onboarding ⇒ Boolean?
Whether number changes are allowed during onboarding
109 |
# File 'lib/sentdm/models/profile_detail.rb', line 109 optional :allow_number_change_during_onboarding, Sentdm::Internal::Type::Boolean, nil?: true |
#allow_template_sharing ⇒ Boolean?
Whether templates are shared across profiles in the organization
115 |
# File 'lib/sentdm/models/profile_detail.rb', line 115 optional :allow_template_sharing, Sentdm::Internal::Type::Boolean |
#billing_model ⇒ String?
Billing model: profile, organization, or profile_and_organization
121 |
# File 'lib/sentdm/models/profile_detail.rb', line 121 optional :billing_model, String |
#inherit_contacts ⇒ Boolean?
Whether this profile inherits contacts from the organization
127 |
# File 'lib/sentdm/models/profile_detail.rb', line 127 optional :inherit_contacts, Sentdm::Internal::Type::Boolean |
#inherit_tcr_brand ⇒ Boolean?
Whether this profile inherits TCR brand from the organization
133 |
# File 'lib/sentdm/models/profile_detail.rb', line 133 optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean |
#inherit_tcr_campaign ⇒ Boolean?
Whether this profile inherits TCR campaign from the organization
139 |
# File 'lib/sentdm/models/profile_detail.rb', line 139 optional :inherit_tcr_campaign, Sentdm::Internal::Type::Boolean |
#inherit_templates ⇒ Boolean?
Whether this profile inherits templates from the organization
145 |
# File 'lib/sentdm/models/profile_detail.rb', line 145 optional :inherit_templates, Sentdm::Internal::Type::Boolean |
#sending_phone_number ⇒ String?
Direct SMS phone number
151 |
# File 'lib/sentdm/models/profile_detail.rb', line 151 optional :sending_phone_number, String, nil?: true |
#sending_phone_number_profile_id ⇒ String?
Reference to another profile for SMS/Telnyx configuration
157 |
# File 'lib/sentdm/models/profile_detail.rb', line 157 optional :sending_phone_number_profile_id, String, nil?: true |
#sending_whatsapp_number_profile_id ⇒ String?
Reference to another profile for WhatsApp configuration
163 |
# File 'lib/sentdm/models/profile_detail.rb', line 163 optional :sending_whatsapp_number_profile_id, String, nil?: true |
#whatsapp_phone_number ⇒ String?
Direct WhatsApp phone number
169 |
# File 'lib/sentdm/models/profile_detail.rb', line 169 optional :whatsapp_phone_number, String, nil?: true |