Class: Sentdm::Models::ProfileSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileSettings
- Defined in:
- lib/sentdm/models/profile_settings.rb
Instance Attribute Summary collapse
-
#allow_contact_sharing ⇒ Boolean?
Whether contacts are shared across profiles in the organization.
-
#allow_template_sharing ⇒ Boolean?
Whether templates are shared across profiles in the organization.
-
#billing_model ⇒ String?
Billing model: profile, organization, or profile_and_organization.
-
#inherit_contacts ⇒ Boolean?
Whether this profile inherits contacts from the organization.
-
#inherit_tcr_brand ⇒ Boolean?
Whether this profile inherits TCR brand from the organization.
-
#inherit_tcr_campaign ⇒ Boolean?
Whether this profile inherits TCR campaign from the organization.
-
#inherit_templates ⇒ Boolean?
Whether this profile inherits templates from the organization.
Instance Method Summary collapse
-
#initialize(allow_contact_sharing: nil, allow_template_sharing: nil, billing_model: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil) ⇒ Object
constructor
Profile configuration settings.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allow_contact_sharing: nil, allow_template_sharing: nil, billing_model: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil) ⇒ Object
Profile configuration settings
|
|
# File 'lib/sentdm/models/profile_settings.rb', line 48
|
Instance Attribute Details
#allow_contact_sharing ⇒ Boolean?
Whether contacts are shared across profiles in the organization
10 |
# File 'lib/sentdm/models/profile_settings.rb', line 10 optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean, nil?: true |
#allow_template_sharing ⇒ Boolean?
Whether templates are shared across profiles in the organization
16 |
# File 'lib/sentdm/models/profile_settings.rb', line 16 optional :allow_template_sharing, Sentdm::Internal::Type::Boolean, nil?: true |
#billing_model ⇒ String?
Billing model: profile, organization, or profile_and_organization
22 |
# File 'lib/sentdm/models/profile_settings.rb', line 22 optional :billing_model, String, nil?: true |
#inherit_contacts ⇒ Boolean?
Whether this profile inherits contacts from the organization
28 |
# File 'lib/sentdm/models/profile_settings.rb', line 28 optional :inherit_contacts, Sentdm::Internal::Type::Boolean, nil?: true |
#inherit_tcr_brand ⇒ Boolean?
Whether this profile inherits TCR brand from the organization
34 |
# File 'lib/sentdm/models/profile_settings.rb', line 34 optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean, nil?: true |