Class: Sentdm::Models::ProfileUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/profile_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(path_profile_id:, allow_contact_sharing: nil, allow_number_change_during_onboarding: nil, allow_template_sharing: nil, billing_model: nil, description: nil, icon: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, name: nil, body_profile_id: nil, sending_phone_number: nil, sending_phone_number_profile_id: nil, sending_whatsapp_number_profile_id: nil, short_name: nil, test_mode: nil, whatsapp_phone_number: nil, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::ProfileUpdateParams for more details.

Parameters:

  • path_profile_id (String)
  • allow_contact_sharing (Boolean, nil) (defaults to: nil)

    Whether contacts are shared across profiles (optional)

  • allow_number_change_during_onboarding (Boolean, nil) (defaults to: nil)

    Whether number changes are allowed during onboarding (optional)

  • allow_template_sharing (Boolean, nil) (defaults to: nil)

    Whether templates are shared across profiles (optional)

  • billing_model (String, nil) (defaults to: nil)

    Billing model: profile, organization, or profile_and_organization (optional)

  • description (String, nil) (defaults to: nil)

    Profile description (optional)

  • icon (String, nil) (defaults to: nil)

    Profile icon URL (optional)

  • inherit_contacts (Boolean, nil) (defaults to: nil)

    Whether this profile inherits contacts from organization (optional)

  • inherit_tcr_brand (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR brand from organization (optional)

  • inherit_tcr_campaign (Boolean, nil) (defaults to: nil)

    Whether this profile inherits TCR campaign from organization (optional)

  • inherit_templates (Boolean, nil) (defaults to: nil)

    Whether this profile inherits templates from organization (optional)

  • name (String, nil) (defaults to: nil)

    Profile name (optional)

  • body_profile_id (String) (defaults to: nil)

    Profile ID from route parameter

  • sending_phone_number (String, nil) (defaults to: nil)

    Direct phone number for SMS sending (optional)

  • sending_phone_number_profile_id (String, nil) (defaults to: nil)

    Reference to another profile to use for SMS/Telnyx configuration (optional)

  • sending_whatsapp_number_profile_id (String, nil) (defaults to: nil)

    Reference to another profile to use for WhatsApp configuration (optional)

  • short_name (String, nil) (defaults to: nil)

    Profile short name/abbreviation (optional)

  • test_mode (Boolean) (defaults to: nil)

    Test mode flag - when true, the operation is simulated without side effects

  • whatsapp_phone_number (String, nil) (defaults to: nil)

    Direct phone number for WhatsApp sending (optional)

  • idempotency_key (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/profile_update_params.rb', line 129

Instance Attribute Details

#allow_contact_sharingBoolean?

Whether contacts are shared across profiles (optional)

Returns:

  • (Boolean, nil)


19
# File 'lib/sentdm/models/profile_update_params.rb', line 19

optional :allow_contact_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#allow_number_change_during_onboardingBoolean?

Whether number changes are allowed during onboarding (optional)

Returns:

  • (Boolean, nil)


25
# File 'lib/sentdm/models/profile_update_params.rb', line 25

optional :allow_number_change_during_onboarding, Sentdm::Internal::Type::Boolean, nil?: true

#allow_template_sharingBoolean?

Whether templates are shared across profiles (optional)

Returns:

  • (Boolean, nil)


31
# File 'lib/sentdm/models/profile_update_params.rb', line 31

optional :allow_template_sharing, Sentdm::Internal::Type::Boolean, nil?: true

#billing_modelString?

Billing model: profile, organization, or profile_and_organization (optional)

Returns:

  • (String, nil)


37
# File 'lib/sentdm/models/profile_update_params.rb', line 37

optional :billing_model, String, nil?: true

#body_profile_idString?

Profile ID from route parameter

Returns:

  • (String, nil)


85
# File 'lib/sentdm/models/profile_update_params.rb', line 85

optional :body_profile_id, String, api_name: :profile_id

#descriptionString?

Profile description (optional)

Returns:

  • (String, nil)


43
# File 'lib/sentdm/models/profile_update_params.rb', line 43

optional :description, String, nil?: true

#iconString?

Profile icon URL (optional)

Returns:

  • (String, nil)


49
# File 'lib/sentdm/models/profile_update_params.rb', line 49

optional :icon, String, nil?: true

#idempotency_keyString?

Returns:

  • (String, nil)


127
# File 'lib/sentdm/models/profile_update_params.rb', line 127

optional :idempotency_key, String

#inherit_contactsBoolean?

Whether this profile inherits contacts from organization (optional)

Returns:

  • (Boolean, nil)


55
# File 'lib/sentdm/models/profile_update_params.rb', line 55

optional :inherit_contacts, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_brandBoolean?

Whether this profile inherits TCR brand from organization (optional)

Returns:

  • (Boolean, nil)


61
# File 'lib/sentdm/models/profile_update_params.rb', line 61

optional :inherit_tcr_brand, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_tcr_campaignBoolean?

Whether this profile inherits TCR campaign from organization (optional)

Returns:

  • (Boolean, nil)


67
# File 'lib/sentdm/models/profile_update_params.rb', line 67

optional :inherit_tcr_campaign, Sentdm::Internal::Type::Boolean, nil?: true

#inherit_templatesBoolean?

Whether this profile inherits templates from organization (optional)

Returns:

  • (Boolean, nil)


73
# File 'lib/sentdm/models/profile_update_params.rb', line 73

optional :inherit_templates, Sentdm::Internal::Type::Boolean, nil?: true

#nameString?

Profile name (optional)

Returns:

  • (String, nil)


79
# File 'lib/sentdm/models/profile_update_params.rb', line 79

optional :name, String, nil?: true

#path_profile_idString

Returns:

  • (String)


13
# File 'lib/sentdm/models/profile_update_params.rb', line 13

required :path_profile_id, String

#sending_phone_numberString?

Direct phone number for SMS sending (optional)

Returns:

  • (String, nil)


91
# File 'lib/sentdm/models/profile_update_params.rb', line 91

optional :sending_phone_number, String, nil?: true

#sending_phone_number_profile_idString?

Reference to another profile to use for SMS/Telnyx configuration (optional)

Returns:

  • (String, nil)


97
# File 'lib/sentdm/models/profile_update_params.rb', line 97

optional :sending_phone_number_profile_id, String, nil?: true

#sending_whatsapp_number_profile_idString?

Reference to another profile to use for WhatsApp configuration (optional)

Returns:

  • (String, nil)


103
# File 'lib/sentdm/models/profile_update_params.rb', line 103

optional :sending_whatsapp_number_profile_id, String, nil?: true

#short_nameString?

Profile short name/abbreviation (optional)

Returns:

  • (String, nil)


109
# File 'lib/sentdm/models/profile_update_params.rb', line 109

optional :short_name, String, nil?: true

#test_modeBoolean?

Test mode flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


116
# File 'lib/sentdm/models/profile_update_params.rb', line 116

optional :test_mode, Sentdm::Internal::Type::Boolean

#whatsapp_phone_numberString?

Direct phone number for WhatsApp sending (optional)

Returns:

  • (String, nil)


122
# File 'lib/sentdm/models/profile_update_params.rb', line 122

optional :whatsapp_phone_number, String, nil?: true