Class: Sentdm::Models::ProfileUpdateParams::BillingContact
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::ProfileUpdateParams::BillingContact
- Defined in:
- lib/sentdm/models/profile_update_params.rb
Instance Attribute Summary collapse
-
#address ⇒ String?
Billing address (optional).
-
#email ⇒ String
Email address where invoices will be sent (required).
-
#name ⇒ String
Full name of the billing contact or company (required).
-
#phone ⇒ String?
Phone number for the billing contact (optional).
Instance Method Summary collapse
-
#initialize(profile_id:, allow_contact_sharing: nil, allow_number_change_during_onboarding: nil, allow_template_sharing: nil, billing_contact: nil, billing_model: nil, brand: nil, description: nil, icon: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, name: nil, payment_details: nil, sandbox: nil, sending_phone_number: nil, sending_phone_number_profile_id: nil, sending_whatsapp_number_profile_id: nil, short_name: nil, whatsapp_phone_number: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Sentdm::Models::ProfileUpdateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(profile_id:, allow_contact_sharing: nil, allow_number_change_during_onboarding: nil, allow_template_sharing: nil, billing_contact: nil, billing_model: nil, brand: nil, description: nil, icon: nil, inherit_contacts: nil, inherit_tcr_brand: nil, inherit_tcr_campaign: nil, inherit_templates: nil, name: nil, payment_details: nil, sandbox: nil, sending_phone_number: nil, sending_phone_number_profile_id: nil, sending_whatsapp_number_profile_id: nil, short_name: nil, whatsapp_phone_number: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::ProfileUpdateParams for more details.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/sentdm/models/profile_update_params.rb', line 209 class BillingContact < Sentdm::Internal::Type::BaseModel # @!attribute email # Email address where invoices will be sent (required) # # @return [String] required :email, String # @!attribute name # Full name of the billing contact or company (required) # # @return [String] required :name, String # @!attribute address # Billing address (optional). Free-form text including street, city, state, postal # code, and country. # # @return [String, nil] optional :address, String, nil?: true # @!attribute phone # Phone number for the billing contact (optional) # # @return [String, nil] optional :phone, String, nil?: true # @!method initialize(email:, name:, address: nil, phone: nil) # Some parameter documentations has been truncated, see # {Sentdm::Models::ProfileUpdateParams::BillingContact} for more details. # # Billing contact information for a profile. Required when billing_model is # "profile" or "profile_and_organization". # # @param email [String] Email address where invoices will be sent (required) # # @param name [String] Full name of the billing contact or company (required) # # @param address [String, nil] Billing address (optional). Free-form text including street, city, state, postal # # @param phone [String, nil] Phone number for the billing contact (optional) end |
Instance Attribute Details
#address ⇒ String?
Billing address (optional). Free-form text including street, city, state, postal code, and country.
227 |
# File 'lib/sentdm/models/profile_update_params.rb', line 227 optional :address, String, nil?: true |
#email ⇒ String
Email address where invoices will be sent (required)
214 |
# File 'lib/sentdm/models/profile_update_params.rb', line 214 required :email, String |
#name ⇒ String
Full name of the billing contact or company (required)
220 |
# File 'lib/sentdm/models/profile_update_params.rb', line 220 required :name, String |
#phone ⇒ String?
Phone number for the billing contact (optional)
233 |
# File 'lib/sentdm/models/profile_update_params.rb', line 233 optional :phone, String, nil?: true |