Class: Sentdm::Models::Profiles::CampaignUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/profiles/campaign_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(profile_id:, campaign_id:, campaign:, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::Profiles::CampaignUpdateParams for more details.

Parameters:

  • profile_id (String)
  • campaign_id (String)
  • campaign (Sentdm::Models::Profiles::CampaignData)

    Campaign data for create or update operation

  • sandbox (Boolean) (defaults to: nil)

    Sandbox flag - when true, the operation is simulated without side effects

  • idempotency_key (String) (defaults to: nil)
  • x_profile_id (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 44

Instance Attribute Details

#campaignSentdm::Models::Profiles::CampaignData

Campaign data for create or update operation



25
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 25

required :campaign, -> { Sentdm::Profiles::CampaignData }

#campaign_idString

Returns:

  • (String)


19
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 19

required :campaign_id, String

#idempotency_keyString?

Returns:

  • (String, nil)


37
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 37

optional :idempotency_key, String

#profile_idString

Returns:

  • (String)


14
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 14

required :profile_id, String

#sandboxBoolean?

Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


32
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 32

optional :sandbox, Sentdm::Internal::Type::Boolean

#x_profile_idString?

Returns:

  • (String, nil)


42
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 42

optional :x_profile_id, String