Class: Sentdm::Models::Profiles::CampaignUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::Profiles::CampaignUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sentdm/models/profiles/campaign_update_params.rb
Overview
Instance Attribute Summary collapse
-
#campaign ⇒ Sentdm::Models::Profiles::CampaignData
Campaign data for create or update operation.
- #campaign_id ⇒ String
- #idempotency_key ⇒ String?
- #profile_id ⇒ String
-
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution.
- #x_profile_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(profile_id:, campaign_id:, campaign:, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CampaignUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(profile_id:, campaign_id:, campaign:, sandbox: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::Profiles::CampaignUpdateParams for more details.
|
|
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 44
|
Instance Attribute Details
#campaign ⇒ Sentdm::Models::Profiles::CampaignData
Campaign data for create or update operation
25 |
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 25 required :campaign, -> { Sentdm::Profiles::CampaignData } |
#campaign_id ⇒ String
19 |
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 19 required :campaign_id, String |
#idempotency_key ⇒ String?
37 |
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 37 optional :idempotency_key, String |
#profile_id ⇒ String
14 |
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 14 required :profile_id, String |
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
32 |
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 32 optional :sandbox, Sentdm::Internal::Type::Boolean |
#x_profile_id ⇒ String?
42 |
# File 'lib/sentdm/models/profiles/campaign_update_params.rb', line 42 optional :x_profile_id, String |