Class: Sentdm::Models::TemplateCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Sentdm::Models::TemplateCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sentdm/models/template_create_params.rb
Overview
Instance Attribute Summary collapse
-
#category ⇒ String?
Template category: MARKETING, UTILITY, AUTHENTICATION (optional, auto-detected if not provided).
-
#creation_source ⇒ String?
Source of template creation (default: from-api).
-
#definition ⇒ Sentdm::Models::TemplateDefinition?
Complete definition of a message template including header, body, footer, and buttons.
- #idempotency_key ⇒ String?
-
#language ⇒ String?
Template language code (e.g., en_US) (optional, auto-detected if not provided).
-
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution.
-
#submit_for_review ⇒ Boolean?
Whether to submit the template for review after creation (default: false).
- #x_profile_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(category: nil, creation_source: nil, definition: nil, language: nil, sandbox: nil, submit_for_review: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TemplateCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category: nil, creation_source: nil, definition: nil, language: nil, sandbox: nil, submit_for_review: nil, idempotency_key: nil, x_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Sentdm::Models::TemplateCreateParams for more details.
|
|
# File 'lib/sentdm/models/template_create_params.rb', line 59
|
Instance Attribute Details
#category ⇒ String?
Template category: MARKETING, UTILITY, AUTHENTICATION (optional, auto-detected if not provided)
15 |
# File 'lib/sentdm/models/template_create_params.rb', line 15 optional :category, String, nil?: true |
#creation_source ⇒ String?
Source of template creation (default: from-api)
21 |
# File 'lib/sentdm/models/template_create_params.rb', line 21 optional :creation_source, String, nil?: true |
#definition ⇒ Sentdm::Models::TemplateDefinition?
Complete definition of a message template including header, body, footer, and buttons
28 |
# File 'lib/sentdm/models/template_create_params.rb', line 28 optional :definition, -> { Sentdm::TemplateDefinition } |
#idempotency_key ⇒ String?
52 |
# File 'lib/sentdm/models/template_create_params.rb', line 52 optional :idempotency_key, String |
#language ⇒ String?
Template language code (e.g., en_US) (optional, auto-detected if not provided)
34 |
# File 'lib/sentdm/models/template_create_params.rb', line 34 optional :language, String, nil?: true |
#sandbox ⇒ Boolean?
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
41 |
# File 'lib/sentdm/models/template_create_params.rb', line 41 optional :sandbox, Sentdm::Internal::Type::Boolean |
#submit_for_review ⇒ Boolean?
Whether to submit the template for review after creation (default: false)
47 |
# File 'lib/sentdm/models/template_create_params.rb', line 47 optional :submit_for_review, Sentdm::Internal::Type::Boolean |
#x_profile_id ⇒ String?
57 |
# File 'lib/sentdm/models/template_create_params.rb', line 57 optional :x_profile_id, String |