Class: Sentdm::Models::TemplateUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sentdm/models/template_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, category: nil, definition: nil, language: nil, name: nil, submit_for_review: nil, test_mode: nil, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Sentdm::Models::TemplateUpdateParams for more details.

Parameters:

  • id (String)
  • category (String, nil) (defaults to: nil)

    Template category: MARKETING, UTILITY, AUTHENTICATION

  • definition (Sentdm::Models::TemplateDefinition, nil) (defaults to: nil)

    Template definition including header, body, footer, and buttons

  • language (String, nil) (defaults to: nil)

    Template language code (e.g., en_US)

  • name (String, nil) (defaults to: nil)

    Template display name

  • submit_for_review (Boolean) (defaults to: nil)

    Whether to submit the template for review after updating (default: false)

  • test_mode (Boolean) (defaults to: nil)

    Test mode flag - when true, the operation is simulated without side effects

  • idempotency_key (String) (defaults to: nil)
  • request_options (Sentdm::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sentdm/models/template_update_params.rb', line 57

Instance Attribute Details

#categoryString?

Template category: MARKETING, UTILITY, AUTHENTICATION

Returns:

  • (String, nil)


19
# File 'lib/sentdm/models/template_update_params.rb', line 19

optional :category, String, nil?: true

#definitionSentdm::Models::TemplateDefinition?

Template definition including header, body, footer, and buttons



25
# File 'lib/sentdm/models/template_update_params.rb', line 25

optional :definition, -> { Sentdm::TemplateDefinition }, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/sentdm/models/template_update_params.rb', line 13

required :id, String

#idempotency_keyString?

Returns:

  • (String, nil)


55
# File 'lib/sentdm/models/template_update_params.rb', line 55

optional :idempotency_key, String

#languageString?

Template language code (e.g., en_US)

Returns:

  • (String, nil)


31
# File 'lib/sentdm/models/template_update_params.rb', line 31

optional :language, String, nil?: true

#nameString?

Template display name

Returns:

  • (String, nil)


37
# File 'lib/sentdm/models/template_update_params.rb', line 37

optional :name, String, nil?: true

#submit_for_reviewBoolean?

Whether to submit the template for review after updating (default: false)

Returns:

  • (Boolean, nil)


43
# File 'lib/sentdm/models/template_update_params.rb', line 43

optional :submit_for_review, Sentdm::Internal::Type::Boolean

#test_modeBoolean?

Test mode flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution

Returns:

  • (Boolean, nil)


50
# File 'lib/sentdm/models/template_update_params.rb', line 50

optional :test_mode, Sentdm::Internal::Type::Boolean